# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from decimal import Decimal
from stripe._stripe_object import UntypedStripeObject
from stripe.v2._amount import AmountParam
from typing import Dict, List, Optional
from typing_extensions import Literal, NotRequired, TypedDict


class AccountTokenCreateParams(TypedDict):
    contact_email: NotRequired[str]
    """
    The primary contact email address for the Account.
    """
    contact_phone: NotRequired[str]
    """
    The default contact phone for the Account.
    """
    display_name: NotRequired[str]
    """
    A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.
    """
    identity: NotRequired["AccountTokenCreateParamsIdentity"]
    """
    Information about the company, individual, and business represented by the Account.
    """


class AccountTokenCreateParamsIdentity(TypedDict):
    attestations: NotRequired["AccountTokenCreateParamsIdentityAttestations"]
    """
    Attestations from the identity's key people, e.g. owners, executives, directors, representatives.
    """
    business_details: NotRequired[
        "AccountTokenCreateParamsIdentityBusinessDetails"
    ]
    """
    Information about the company or business.
    """
    entity_type: NotRequired[
        Literal["company", "government_entity", "individual", "non_profit"]
    ]
    """
    The entity type.
    """
    individual: NotRequired["AccountTokenCreateParamsIdentityIndividual"]
    """
    Information about the person represented by the account.
    """


class AccountTokenCreateParamsIdentityAttestations(TypedDict):
    directorship_declaration: NotRequired[
        "AccountTokenCreateParamsIdentityAttestationsDirectorshipDeclaration"
    ]
    """
    This hash is used to attest that the directors information provided to Stripe is both current and correct; IP, date, and User Agent are expanded by Stripe.
    """
    ownership_declaration: NotRequired[
        "AccountTokenCreateParamsIdentityAttestationsOwnershipDeclaration"
    ]
    """
    This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct; IP, date, and User Agent are expanded by Stripe.
    """
    persons_provided: NotRequired[
        "AccountTokenCreateParamsIdentityAttestationsPersonsProvided"
    ]
    """
    Attestation that all Persons with a specific Relationship value have been provided.
    """
    representative_declaration: NotRequired[
        "AccountTokenCreateParamsIdentityAttestationsRepresentativeDeclaration"
    ]
    """
    This hash is used to attest that the representative is authorized to act as the representative of their legal entity; IP, date, and User Agent are expanded by Stripe.
    """
    terms_of_service: NotRequired[
        "AccountTokenCreateParamsIdentityAttestationsTermsOfService"
    ]
    """
    Attestations of accepted terms of service agreements.
    """


class AccountTokenCreateParamsIdentityAttestationsDirectorshipDeclaration(
    TypedDict,
):
    attested: NotRequired[bool]
    """
    A boolean indicating if the directors information has been attested.
    """


class AccountTokenCreateParamsIdentityAttestationsOwnershipDeclaration(
    TypedDict,
):
    attested: NotRequired[bool]
    """
    A boolean indicating if the beneficial owner information has been attested.
    """


class AccountTokenCreateParamsIdentityAttestationsPersonsProvided(TypedDict):
    directors: NotRequired[bool]
    """
    Whether the company's directors have been provided. Set this Boolean to true after creating all the company's directors with the [Persons API](https://docs.stripe.com/api/v2/core/accounts/createperson).
    """
    executives: NotRequired[bool]
    """
    Whether the company's executives have been provided. Set this Boolean to true after creating all the company's executives with the [Persons API](https://docs.stripe.com/api/v2/core/accounts/createperson).
    """
    owners: NotRequired[bool]
    """
    Whether the company's owners have been provided. Set this Boolean to true after creating all the company's owners with the [Persons API](https://docs.stripe.com/api/v2/core/accounts/createperson).
    """
    ownership_exemption_reason: NotRequired[
        Literal[
            "qualified_entity_exceeds_ownership_threshold",
            "qualifies_as_financial_institution",
        ]
    ]
    """
    Reason for why the company is exempt from providing ownership information.
    """


class AccountTokenCreateParamsIdentityAttestationsRepresentativeDeclaration(
    TypedDict,
):
    attested: NotRequired[bool]
    """
    A boolean indicating if the representative is authorized to act as the representative of their legal entity.
    """


class AccountTokenCreateParamsIdentityAttestationsTermsOfService(TypedDict):
    account: NotRequired[
        "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceAccount"
    ]
    """
    Details on the Account's acceptance of the [Stripe Services Agreement]; IP, date, and User Agent are expanded by Stripe.
    """
    card_creator: NotRequired[
        "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreator"
    ]
    """
    Details on the Account's acceptance of Issuing-specific terms of service.
    """
    crypto_money_manager: NotRequired[
        "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCryptoMoneyManager"
    ]
    """
    Details on the Account's acceptance of Crypto-specific terms of service; IP, date, and User Agent are expanded by Stripe.
    """
    money_manager: NotRequired[
        "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceMoneyManager"
    ]
    """
    Details on the Account's acceptance of Treasury-specific terms of service; IP, date, and User Agent are expanded by Stripe.
    """


class AccountTokenCreateParamsIdentityAttestationsTermsOfServiceAccount(
    TypedDict,
):
    shown_and_accepted: NotRequired[bool]
    """
    The boolean value indicating if the terms of service have been accepted.
    """


class AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreator(
    TypedDict,
):
    commercial: NotRequired[
        "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercial"
    ]
    """
    Terms of service acceptances to create cards for commercial issuing use cases.
    """


class AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercial(
    TypedDict,
):
    account_holder: NotRequired[
        "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialAccountHolder"
    ]
    """
    Terms of service acceptances for Stripe commercial card issuing.
    """
    celtic: NotRequired[
        "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCeltic"
    ]
    """
    Terms of service acceptances for commercial issuing cards with Celtic as BIN sponsor.
    """
    cross_river_bank: NotRequired[
        "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBank"
    ]
    """
    Terms of service acceptances for commercial issuing cards with Cross River Bank as BIN sponsor.
    """


class AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialAccountHolder(
    TypedDict,
):
    shown_and_accepted: NotRequired[bool]
    """
    The boolean value indicating if the terms of service have been accepted.
    """


class AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCeltic(
    TypedDict,
):
    apple_pay: NotRequired[
        "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticApplePay"
    ]
    """
    Terms of service acceptances for commercial issuing Apple Pay cards with Celtic as BIN sponsor.
    """
    charge_card: NotRequired[
        "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCard"
    ]
    """
    Terms of service acceptances for commercial issuing charge cards with Celtic as BIN sponsor.
    """
    spend_card: NotRequired[
        "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCard"
    ]
    """
    Terms of service acceptances for commercial issuing spend cards with Celtic as BIN sponsor.
    """


class AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticApplePay(
    TypedDict,
):
    shown_and_accepted: NotRequired[bool]
    """
    The boolean value indicating if the terms of service have been accepted.
    """


class AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCard(
    TypedDict,
):
    bank_terms: NotRequired[
        "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCardBankTerms"
    ]
    """
    Bank terms of service acceptance for commercial issuing charge cards with Celtic as BIN sponsor.
    """
    platform: NotRequired[
        "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCardPlatform"
    ]
    """
    Platform terms of service acceptance for commercial issuing charge cards with Celtic as BIN sponsor.
    """


class AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCardBankTerms(
    TypedDict,
):
    shown_and_accepted: NotRequired[bool]
    """
    The boolean value indicating if the terms of service have been accepted.
    """


class AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCardPlatform(
    TypedDict,
):
    shown_and_accepted: NotRequired[bool]
    """
    The boolean value indicating if the terms of service have been accepted.
    """


class AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCard(
    TypedDict,
):
    bank_terms: NotRequired[
        "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardBankTerms"
    ]
    """
    Bank terms of service acceptance for commercial issuing spend cards with Celtic as BIN sponsor.
    """
    financing_disclosures: NotRequired[
        "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardFinancingDisclosures"
    ]
    """
    Financial disclosures terms of service acceptance for commercial issuing spend cards with Celtic as BIN sponsor.
    """
    platform: NotRequired[
        "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardPlatform"
    ]
    """
    Platform terms of service acceptance for commercial issuing spend cards with Celtic as BIN sponsor.
    """


class AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardBankTerms(
    TypedDict,
):
    shown_and_accepted: NotRequired[bool]
    """
    The boolean value indicating if the terms of service have been accepted.
    """


class AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardFinancingDisclosures(
    TypedDict,
):
    shown_and_accepted: NotRequired[bool]
    """
    The boolean value indicating if the terms of service have been accepted.
    """


class AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardPlatform(
    TypedDict,
):
    shown_and_accepted: NotRequired[bool]
    """
    The boolean value indicating if the terms of service have been accepted.
    """


class AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBank(
    TypedDict,
):
    apple_pay: NotRequired[
        "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankApplePay"
    ]
    """
    Terms of service acceptances for commercial issuing Apple Pay cards with Cross River Bank as BIN sponsor.
    """
    charge_card: NotRequired[
        "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCard"
    ]
    """
    Terms of service acceptances for commercial issuing charge cards with Cross River Bank as BIN sponsor.
    """
    spend_card: NotRequired[
        "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCard"
    ]
    """
    Terms of service acceptances for commercial issuing spend cards with Cross River Bank as BIN sponsor.
    """


class AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankApplePay(
    TypedDict,
):
    shown_and_accepted: NotRequired[bool]
    """
    The boolean value indicating if the terms of service have been accepted.
    """


class AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCard(
    TypedDict,
):
    bank_terms: NotRequired[
        "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardBankTerms"
    ]
    """
    Bank terms of service acceptance for commercial issuing charge cards with Cross River Bank as BIN sponsor.
    """
    financing_disclosures: NotRequired[
        "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardFinancingDisclosures"
    ]
    """
    Financial disclosures terms of service acceptance for commercial issuing charge cards with Cross River Bank as BIN sponsor.
    """
    platform: NotRequired[
        "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardPlatform"
    ]
    """
    Platform terms of service acceptance for commercial issuing charge cards with Cross River Bank as BIN sponsor.
    """


class AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardBankTerms(
    TypedDict,
):
    shown_and_accepted: NotRequired[bool]
    """
    The boolean value indicating if the terms of service have been accepted.
    """


class AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardFinancingDisclosures(
    TypedDict,
):
    shown_and_accepted: NotRequired[bool]
    """
    The boolean value indicating if the terms of service have been accepted.
    """


class AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardPlatform(
    TypedDict,
):
    shown_and_accepted: NotRequired[bool]
    """
    The boolean value indicating if the terms of service have been accepted.
    """


class AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCard(
    TypedDict,
):
    bank_terms: NotRequired[
        "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCardBankTerms"
    ]
    """
    Bank terms of service acceptance for commercial issuing spend cards with Cross River Bank as BIN sponsor.
    """
    financing_disclosures: NotRequired[
        "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCardFinancingDisclosures"
    ]
    """
    Financial disclosures terms of service acceptance for commercial issuing spend cards with Cross River Bank as BIN sponsor.
    """


class AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCardBankTerms(
    TypedDict,
):
    shown_and_accepted: NotRequired[bool]
    """
    The boolean value indicating if the terms of service have been accepted.
    """


class AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCardFinancingDisclosures(
    TypedDict,
):
    shown_and_accepted: NotRequired[bool]
    """
    The boolean value indicating if the terms of service have been accepted.
    """


class AccountTokenCreateParamsIdentityAttestationsTermsOfServiceCryptoMoneyManager(
    TypedDict,
):
    shown_and_accepted: NotRequired[bool]
    """
    The boolean value indicating if the terms of service have been accepted.
    """


class AccountTokenCreateParamsIdentityAttestationsTermsOfServiceMoneyManager(
    TypedDict,
):
    shown_and_accepted: NotRequired[bool]
    """
    The boolean value indicating if the terms of service have been accepted.
    """


class AccountTokenCreateParamsIdentityBusinessDetails(TypedDict):
    address: NotRequired[
        "AccountTokenCreateParamsIdentityBusinessDetailsAddress"
    ]
    """
    The business registration address of the business entity.
    """
    annual_revenue: NotRequired[
        "AccountTokenCreateParamsIdentityBusinessDetailsAnnualRevenue"
    ]
    """
    The business gross annual revenue for its preceding fiscal year.
    """
    compliance_screening_description: NotRequired[str]
    """
    A detailed description of the business's compliance and anti-money laundering controls and practices.
    """
    documents: NotRequired[
        "AccountTokenCreateParamsIdentityBusinessDetailsDocuments"
    ]
    """
    A document verifying the business.
    """
    estimated_worker_count: NotRequired[int]
    """
    Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
    """
    id_numbers: NotRequired[
        List["AccountTokenCreateParamsIdentityBusinessDetailsIdNumber"]
    ]
    """
    The ID numbers of a business entity.
    """
    monthly_estimated_revenue: NotRequired[
        "AccountTokenCreateParamsIdentityBusinessDetailsMonthlyEstimatedRevenue"
    ]
    """
    An estimate of the monthly revenue of the business.
    """
    phone: NotRequired[str]
    """
    The phone number of the Business Entity.
    """
    registered_name: NotRequired[str]
    """
    The business legal name.
    """
    registration_date: NotRequired[
        "AccountTokenCreateParamsIdentityBusinessDetailsRegistrationDate"
    ]
    """
    When the business was incorporated or registered.
    """
    script_addresses: NotRequired[
        "AccountTokenCreateParamsIdentityBusinessDetailsScriptAddresses"
    ]
    """
    The business registration address of the business entity in non latin script.
    """
    script_names: NotRequired[
        "AccountTokenCreateParamsIdentityBusinessDetailsScriptNames"
    ]
    """
    The business legal name in non latin script.
    """
    structure: NotRequired[
        Literal[
            "cooperative",
            "free_zone_establishment",
            "free_zone_llc",
            "governmental_unit",
            "government_instrumentality",
            "incorporated_association",
            "incorporated_non_profit",
            "incorporated_partnership",
            "limited_liability_partnership",
            "llc",
            "multi_member_llc",
            "private_company",
            "private_corporation",
            "private_partnership",
            "public_company",
            "public_corporation",
            "public_listed_corporation",
            "public_partnership",
            "registered_charity",
            "single_member_llc",
            "sole_establishment",
            "sole_proprietorship",
            "tax_exempt_government_instrumentality",
            "trust",
            "unincorporated_association",
            "unincorporated_non_profit",
            "unincorporated_partnership",
        ]
    ]
    """
    The category identifying the legal structure of the business.
    """


class AccountTokenCreateParamsIdentityBusinessDetailsAddress(TypedDict):
    city: NotRequired[str]
    """
    City, district, suburb, town, or village.
    """
    country: NotRequired[str]
    """
    Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
    """
    line1: NotRequired[str]
    """
    Address line 1 (e.g., street, PO Box, or company name).
    """
    line2: NotRequired[str]
    """
    Address line 2 (e.g., apartment, suite, unit, or building).
    """
    postal_code: NotRequired[str]
    """
    ZIP or postal code.
    """
    state: NotRequired[str]
    """
    State, county, province, or region.
    """
    town: NotRequired[str]
    """
    Town or district.
    """


class AccountTokenCreateParamsIdentityBusinessDetailsAnnualRevenue(TypedDict):
    amount: NotRequired[AmountParam]
    """
    A non-negative integer representing the amount in the smallest currency unit.
    """
    fiscal_year_end: NotRequired[str]
    """
    The close-out date of the preceding fiscal year in ISO 8601 format. E.g. 2023-12-31 for the 31st of December, 2023.
    """


class AccountTokenCreateParamsIdentityBusinessDetailsDocuments(TypedDict):
    bank_account_ownership_verification: NotRequired[
        "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsBankAccountOwnershipVerification"
    ]
    """
    One or more documents that support the bank account ownership verification requirement. Must be a document associated with the account's primary active bank account that displays the last 4 digits of the account number, either a statement or a check.
    """
    company_license: NotRequired[
        "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyLicense"
    ]
    """
    One or more documents that demonstrate proof of a company's license to operate.
    """
    company_memorandum_of_association: NotRequired[
        "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyMemorandumOfAssociation"
    ]
    """
    One or more documents showing the company's Memorandum of Association.
    """
    company_ministerial_decree: NotRequired[
        "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyMinisterialDecree"
    ]
    """
    Certain countries only: One or more documents showing the ministerial decree legalizing the company's establishment.
    """
    company_registration_verification: NotRequired[
        "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyRegistrationVerification"
    ]
    """
    One or more documents that demonstrate proof of a company's registration with the appropriate local authorities.
    """
    company_tax_id_verification: NotRequired[
        "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyTaxIdVerification"
    ]
    """
    One or more documents that demonstrate proof of a company's tax ID.
    """
    primary_verification: NotRequired[
        "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerification"
    ]
    """
    A document verifying the business.
    """
    proof_of_address: NotRequired[
        "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfAddress"
    ]
    """
    One or more documents that demonstrate proof of address.
    """
    proof_of_registration: NotRequired[
        "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistration"
    ]
    """
    One or more documents that demonstrate proof of ultimate beneficial ownership.
    """
    proof_of_ultimate_beneficial_ownership: NotRequired[
        "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnership"
    ]
    """
    One or more documents that demonstrate proof of ultimate beneficial ownership.
    """


class AccountTokenCreateParamsIdentityBusinessDetailsDocumentsBankAccountOwnershipVerification(
    TypedDict,
):
    files: List[str]
    """
    One or more document IDs returned by a [file upload](https://docs.stripe.com/api/persons/update#create_file) with a purpose value of `account_requirement`.
    """
    type: Literal["files"]
    """
    The format of the document. Currently supports `files` only.
    """


class AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyLicense(
    TypedDict,
):
    files: List[str]
    """
    One or more document IDs returned by a [file upload](https://docs.stripe.com/api/persons/update#create_file) with a purpose value of `account_requirement`.
    """
    type: Literal["files"]
    """
    The format of the document. Currently supports `files` only.
    """


class AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyMemorandumOfAssociation(
    TypedDict,
):
    files: List[str]
    """
    One or more document IDs returned by a [file upload](https://docs.stripe.com/api/persons/update#create_file) with a purpose value of `account_requirement`.
    """
    type: Literal["files"]
    """
    The format of the document. Currently supports `files` only.
    """


class AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyMinisterialDecree(
    TypedDict,
):
    files: List[str]
    """
    One or more document IDs returned by a [file upload](https://docs.stripe.com/api/persons/update#create_file) with a purpose value of `account_requirement`.
    """
    type: Literal["files"]
    """
    The format of the document. Currently supports `files` only.
    """


class AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyRegistrationVerification(
    TypedDict,
):
    files: List[str]
    """
    One or more document IDs returned by a [file upload](https://docs.stripe.com/api/persons/update#create_file) with a purpose value of `account_requirement`.
    """
    type: Literal["files"]
    """
    The format of the document. Currently supports `files` only.
    """


class AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyTaxIdVerification(
    TypedDict,
):
    files: List[str]
    """
    One or more document IDs returned by a [file upload](https://docs.stripe.com/api/persons/update#create_file) with a purpose value of `account_requirement`.
    """
    type: Literal["files"]
    """
    The format of the document. Currently supports `files` only.
    """


class AccountTokenCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerification(
    TypedDict,
):
    front_back: "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerificationFrontBack"
    """
    The [file upload](https://docs.stripe.com/api/persons/update#create_file) tokens referring to each side of the document.
    """
    type: Literal["front_back"]
    """
    The format of the verification document. Currently supports `front_back` only.
    """


class AccountTokenCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerificationFrontBack(
    TypedDict,
):
    back: NotRequired[str]
    """
    A [file upload](https://docs.stripe.com/api/persons/update#create_file) token representing the back of the verification document. The purpose of the uploaded file should be 'identity_document'. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.
    """
    front: NotRequired[str]
    """
    A [file upload](https://docs.stripe.com/api/persons/update#create_file) token representing the front of the verification document. The purpose of the uploaded file should be 'identity_document'. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.
    """


class AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfAddress(
    TypedDict,
):
    files: List[str]
    """
    One or more document IDs returned by a [file upload](https://docs.stripe.com/api/persons/update#create_file) with a purpose value of `account_requirement`.
    """
    type: Literal["files"]
    """
    The format of the document. Currently supports `files` only.
    """


class AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistration(
    TypedDict,
):
    files: List[str]
    """
    One or more document IDs returned by a [file upload](https://docs.stripe.com/api/persons/update#create_file) with a purpose value of `account_requirement`.
    """
    signer: NotRequired[
        "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistrationSigner"
    ]
    """
    Person that is signing the document.
    """
    type: Literal["files"]
    """
    The format of the document. Currently supports `files` only.
    """


class AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistrationSigner(
    TypedDict,
):
    person: str
    """
    Person signing the document.
    """


class AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnership(
    TypedDict,
):
    files: List[str]
    """
    One or more document IDs returned by a [file upload](https://docs.stripe.com/api/persons/update#create_file) with a purpose value of `account_requirement`.
    """
    signer: NotRequired[
        "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnershipSigner"
    ]
    """
    Person that is signing the document.
    """
    type: Literal["files"]
    """
    The format of the document. Currently supports `files` only.
    """


class AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnershipSigner(
    TypedDict,
):
    person: str
    """
    Person signing the document.
    """


class AccountTokenCreateParamsIdentityBusinessDetailsIdNumber(TypedDict):
    registrar: NotRequired[str]
    """
    The registrar of the ID number (Only valid for DE ID number types).
    """
    type: Literal[
        "ae_crn",
        "ae_vat",
        "ao_nif",
        "ar_cuit",
        "at_fn",
        "at_stn",
        "at_vat",
        "au_abn",
        "au_acn",
        "au_in",
        "az_tin",
        "bd_etin",
        "be_cbe",
        "be_vat",
        "bg_uic",
        "bg_vat",
        "bm_crn",
        "bo_tin",
        "br_cnpj",
        "bt_tpn",
        "ca_cn",
        "ca_crarr",
        "ca_gst_hst",
        "ca_neq",
        "ca_rid",
        "ch_chid",
        "ch_uid",
        "co_nit",
        "cr_cpj",
        "cr_nite",
        "cy_he",
        "cy_tic",
        "cy_vat",
        "cz_ico",
        "cz_vat",
        "de_hrn",
        "de_stn",
        "de_vat",
        "dk_cvr",
        "dk_vat",
        "do_rcn",
        "ec_ruc",
        "ee_rk",
        "ee_vat",
        "eg_tin",
        "es_cif",
        "es_vat",
        "fi_vat",
        "fi_yt",
        "fr_rna",
        "fr_siren",
        "fr_vat",
        "gb_crn",
        "gb_vat",
        "gh_tin",
        "gi_crn",
        "gr_afm",
        "gr_gemi",
        "gr_vat",
        "gt_nit",
        "gy_tin",
        "hk_br",
        "hk_cr",
        "hn_rtn",
        "hr_mbs",
        "hr_oib",
        "hr_vat",
        "hu_cjs",
        "hu_tin",
        "hu_vat",
        "ie_crn",
        "ie_trn",
        "ie_vat",
        "it_rea",
        "it_vat",
        "jm_trn",
        "jo_crn",
        "jp_cn",
        "ke_pin",
        "ky_crn",
        "kz_bin",
        "li_uid",
        "lk_tin",
        "lt_ccrn",
        "lt_vat",
        "lu_nif",
        "lu_rcs",
        "lu_vat",
        "lv_urn",
        "lv_vat",
        "mo_tin",
        "mt_crn",
        "mt_tin",
        "mt_vat",
        "mv_tin",
        "mx_rfc",
        "my_brn",
        "my_coid",
        "my_itn",
        "my_sst",
        "mz_nuit",
        "ng_tin",
        "nl_kvk",
        "nl_rsin",
        "nl_vat",
        "no_orgnr",
        "nz_bn",
        "nz_ird",
        "pa_ruc",
        "pe_ruc",
        "ph_tin",
        "pk_ntn",
        "pl_nip",
        "pl_regon",
        "pl_vat",
        "pt_vat",
        "py_ruc",
        "ro_cui",
        "ro_orc",
        "ro_vat",
        "sa_crn",
        "sa_tin",
        "se_orgnr",
        "se_vat",
        "sg_uen",
        "si_msp",
        "si_tin",
        "si_vat",
        "sk_dic",
        "sk_ico",
        "sk_vat",
        "sl_tin",
        "sv_nit",
        "th_crn",
        "th_prn",
        "th_tin",
        "us_ein",
        "uy_ruc",
        "vg_cn",
        "za_tin",
    ]
    """
    Open Enum. The ID number type of a business entity.
    """
    value: str
    """
    The value of the ID number.
    """


class AccountTokenCreateParamsIdentityBusinessDetailsMonthlyEstimatedRevenue(
    TypedDict,
):
    amount: NotRequired[AmountParam]
    """
    A non-negative integer representing the amount in the smallest currency unit.
    """


class AccountTokenCreateParamsIdentityBusinessDetailsRegistrationDate(
    TypedDict,
):
    day: int
    """
    The day of registration, between 1 and 31.
    """
    month: int
    """
    The month of registration, between 1 and 12.
    """
    year: int
    """
    The four-digit year of registration.
    """


class AccountTokenCreateParamsIdentityBusinessDetailsScriptAddresses(
    TypedDict
):
    kana: NotRequired[
        "AccountTokenCreateParamsIdentityBusinessDetailsScriptAddressesKana"
    ]
    """
    Kana Address.
    """
    kanji: NotRequired[
        "AccountTokenCreateParamsIdentityBusinessDetailsScriptAddressesKanji"
    ]
    """
    Kanji Address.
    """


class AccountTokenCreateParamsIdentityBusinessDetailsScriptAddressesKana(
    TypedDict,
):
    city: NotRequired[str]
    """
    City, district, suburb, town, or village.
    """
    country: NotRequired[str]
    """
    Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
    """
    line1: NotRequired[str]
    """
    Address line 1 (e.g., street, PO Box, or company name).
    """
    line2: NotRequired[str]
    """
    Address line 2 (e.g., apartment, suite, unit, or building).
    """
    postal_code: NotRequired[str]
    """
    ZIP or postal code.
    """
    state: NotRequired[str]
    """
    State, county, province, or region.
    """
    town: NotRequired[str]
    """
    Town or district.
    """


class AccountTokenCreateParamsIdentityBusinessDetailsScriptAddressesKanji(
    TypedDict,
):
    city: NotRequired[str]
    """
    City, district, suburb, town, or village.
    """
    country: NotRequired[str]
    """
    Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
    """
    line1: NotRequired[str]
    """
    Address line 1 (e.g., street, PO Box, or company name).
    """
    line2: NotRequired[str]
    """
    Address line 2 (e.g., apartment, suite, unit, or building).
    """
    postal_code: NotRequired[str]
    """
    ZIP or postal code.
    """
    state: NotRequired[str]
    """
    State, county, province, or region.
    """
    town: NotRequired[str]
    """
    Town or district.
    """


class AccountTokenCreateParamsIdentityBusinessDetailsScriptNames(TypedDict):
    kana: NotRequired[
        "AccountTokenCreateParamsIdentityBusinessDetailsScriptNamesKana"
    ]
    """
    Kana name.
    """
    kanji: NotRequired[
        "AccountTokenCreateParamsIdentityBusinessDetailsScriptNamesKanji"
    ]
    """
    Kanji name.
    """


class AccountTokenCreateParamsIdentityBusinessDetailsScriptNamesKana(
    TypedDict
):
    registered_name: NotRequired[str]
    """
    Registered name of the business.
    """


class AccountTokenCreateParamsIdentityBusinessDetailsScriptNamesKanji(
    TypedDict,
):
    registered_name: NotRequired[str]
    """
    Registered name of the business.
    """


class AccountTokenCreateParamsIdentityIndividual(TypedDict):
    additional_addresses: NotRequired[
        List["AccountTokenCreateParamsIdentityIndividualAdditionalAddress"]
    ]
    """
    Additional addresses associated with the individual.
    """
    additional_names: NotRequired[
        List["AccountTokenCreateParamsIdentityIndividualAdditionalName"]
    ]
    """
    Additional names (e.g. aliases) associated with the individual.
    """
    address: NotRequired["AccountTokenCreateParamsIdentityIndividualAddress"]
    """
    The individual's residential address.
    """
    date_of_birth: NotRequired[
        "AccountTokenCreateParamsIdentityIndividualDateOfBirth"
    ]
    """
    The individual's date of birth.
    """
    documents: NotRequired[
        "AccountTokenCreateParamsIdentityIndividualDocuments"
    ]
    """
    Documents that may be submitted to satisfy various informational requests.
    """
    email: NotRequired[str]
    """
    The individual's email address. You can only set this field when the Account is configured as a `merchant` or `recipient`. Use `contact_email` as the primary contact email for this Account.
    """
    given_name: NotRequired[str]
    """
    The individual's first name.
    """
    id_numbers: NotRequired[
        List["AccountTokenCreateParamsIdentityIndividualIdNumber"]
    ]
    """
    The identification numbers (e.g., SSN) associated with the individual.
    """
    legal_gender: NotRequired[Literal["female", "male"]]
    """
    The individual's gender (International regulations require either "male" or "female").
    """
    metadata: NotRequired[
        "Dict[str, Optional[str]]|UntypedStripeObject[Optional[str]]"
    ]
    """
    Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
    """
    nationalities: NotRequired[List[str]]
    """
    The countries where the individual is a national. Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
    """
    phone: NotRequired[str]
    """
    The individual's phone number.
    """
    political_exposure: NotRequired[Literal["existing", "none"]]
    """
    The individual's political exposure.
    """
    relationship: NotRequired[
        "AccountTokenCreateParamsIdentityIndividualRelationship"
    ]
    """
    The relationship that this individual has with the account's identity.
    """
    script_addresses: NotRequired[
        "AccountTokenCreateParamsIdentityIndividualScriptAddresses"
    ]
    """
    The script addresses (e.g., non-Latin characters) associated with the individual.
    """
    script_names: NotRequired[
        "AccountTokenCreateParamsIdentityIndividualScriptNames"
    ]
    """
    The individuals primary name in non latin script.
    """
    surname: NotRequired[str]
    """
    The individual's last name.
    """


class AccountTokenCreateParamsIdentityIndividualAdditionalAddress(TypedDict):
    city: NotRequired[str]
    """
    City, district, suburb, town, or village.
    """
    country: NotRequired[str]
    """
    Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
    """
    line1: NotRequired[str]
    """
    Address line 1 (e.g., street, PO Box, or company name).
    """
    line2: NotRequired[str]
    """
    Address line 2 (e.g., apartment, suite, unit, or building).
    """
    postal_code: NotRequired[str]
    """
    ZIP or postal code.
    """
    purpose: Literal["registered"]
    """
    Purpose of additional address.
    """
    state: NotRequired[str]
    """
    State, county, province, or region.
    """
    town: NotRequired[str]
    """
    Town or district.
    """


class AccountTokenCreateParamsIdentityIndividualAdditionalName(TypedDict):
    full_name: NotRequired[str]
    """
    The person's full name.
    """
    given_name: NotRequired[str]
    """
    The person's first or given name.
    """
    purpose: Literal["alias", "maiden"]
    """
    The purpose or type of the additional name.
    """
    surname: NotRequired[str]
    """
    The person's last or family name.
    """


class AccountTokenCreateParamsIdentityIndividualAddress(TypedDict):
    city: NotRequired[str]
    """
    City, district, suburb, town, or village.
    """
    country: NotRequired[str]
    """
    Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
    """
    line1: NotRequired[str]
    """
    Address line 1 (e.g., street, PO Box, or company name).
    """
    line2: NotRequired[str]
    """
    Address line 2 (e.g., apartment, suite, unit, or building).
    """
    postal_code: NotRequired[str]
    """
    ZIP or postal code.
    """
    state: NotRequired[str]
    """
    State, county, province, or region.
    """
    town: NotRequired[str]
    """
    Town or district.
    """


class AccountTokenCreateParamsIdentityIndividualDateOfBirth(TypedDict):
    day: int
    """
    The day of the birth.
    """
    month: int
    """
    The month of birth.
    """
    year: int
    """
    The year of birth.
    """


class AccountTokenCreateParamsIdentityIndividualDocuments(TypedDict):
    company_authorization: NotRequired[
        "AccountTokenCreateParamsIdentityIndividualDocumentsCompanyAuthorization"
    ]
    """
    One or more documents that demonstrate proof that this person is authorized to represent the company.
    """
    passport: NotRequired[
        "AccountTokenCreateParamsIdentityIndividualDocumentsPassport"
    ]
    """
    One or more documents showing the person's passport page with photo and personal data.
    """
    primary_verification: NotRequired[
        "AccountTokenCreateParamsIdentityIndividualDocumentsPrimaryVerification"
    ]
    """
    An identifying document showing the person's name, either a passport or local ID card.
    """
    secondary_verification: NotRequired[
        "AccountTokenCreateParamsIdentityIndividualDocumentsSecondaryVerification"
    ]
    """
    A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.
    """
    visa: NotRequired[
        "AccountTokenCreateParamsIdentityIndividualDocumentsVisa"
    ]
    """
    One or more documents showing the person's visa required for living in the country where they are residing.
    """


class AccountTokenCreateParamsIdentityIndividualDocumentsCompanyAuthorization(
    TypedDict,
):
    files: List[str]
    """
    One or more document IDs returned by a [file upload](https://docs.stripe.com/api/persons/update#create_file) with a purpose value of `account_requirement`.
    """
    type: Literal["files"]
    """
    The format of the document. Currently supports `files` only.
    """


class AccountTokenCreateParamsIdentityIndividualDocumentsPassport(TypedDict):
    files: List[str]
    """
    One or more document IDs returned by a [file upload](https://docs.stripe.com/api/persons/update#create_file) with a purpose value of `account_requirement`.
    """
    type: Literal["files"]
    """
    The format of the document. Currently supports `files` only.
    """


class AccountTokenCreateParamsIdentityIndividualDocumentsPrimaryVerification(
    TypedDict,
):
    front_back: "AccountTokenCreateParamsIdentityIndividualDocumentsPrimaryVerificationFrontBack"
    """
    The [file upload](https://docs.stripe.com/api/persons/update#create_file) tokens referring to each side of the document.
    """
    type: Literal["front_back"]
    """
    The format of the verification document. Currently supports `front_back` only.
    """


class AccountTokenCreateParamsIdentityIndividualDocumentsPrimaryVerificationFrontBack(
    TypedDict,
):
    back: NotRequired[str]
    """
    A [file upload](https://docs.stripe.com/api/persons/update#create_file) token representing the back of the verification document. The purpose of the uploaded file should be 'identity_document'. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.
    """
    front: NotRequired[str]
    """
    A [file upload](https://docs.stripe.com/api/persons/update#create_file) token representing the front of the verification document. The purpose of the uploaded file should be 'identity_document'. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.
    """


class AccountTokenCreateParamsIdentityIndividualDocumentsSecondaryVerification(
    TypedDict,
):
    front_back: "AccountTokenCreateParamsIdentityIndividualDocumentsSecondaryVerificationFrontBack"
    """
    The [file upload](https://docs.stripe.com/api/persons/update#create_file) tokens referring to each side of the document.
    """
    type: Literal["front_back"]
    """
    The format of the verification document. Currently supports `front_back` only.
    """


class AccountTokenCreateParamsIdentityIndividualDocumentsSecondaryVerificationFrontBack(
    TypedDict,
):
    back: NotRequired[str]
    """
    A [file upload](https://docs.stripe.com/api/persons/update#create_file) token representing the back of the verification document. The purpose of the uploaded file should be 'identity_document'. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.
    """
    front: NotRequired[str]
    """
    A [file upload](https://docs.stripe.com/api/persons/update#create_file) token representing the front of the verification document. The purpose of the uploaded file should be 'identity_document'. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.
    """


class AccountTokenCreateParamsIdentityIndividualDocumentsVisa(TypedDict):
    files: List[str]
    """
    One or more document IDs returned by a [file upload](https://docs.stripe.com/api/persons/update#create_file) with a purpose value of `account_requirement`.
    """
    type: Literal["files"]
    """
    The format of the document. Currently supports `files` only.
    """


class AccountTokenCreateParamsIdentityIndividualIdNumber(TypedDict):
    type: Literal[
        "ae_eid",
        "ao_nif",
        "ar_cuil",
        "ar_dni",
        "at_stn",
        "az_tin",
        "bd_brc",
        "bd_etin",
        "bd_nid",
        "be_nrn",
        "bg_ucn",
        "bm_pp",
        "bn_nric",
        "bo_ci",
        "br_cpf",
        "bt_cid",
        "ca_sin",
        "ch_oasi",
        "cl_rut",
        "cn_pp",
        "co_nuip",
        "cr_ci",
        "cr_cpf",
        "cr_dimex",
        "cr_nite",
        "cy_tic",
        "cz_rc",
        "de_stn",
        "dk_cpr",
        "do_cie",
        "do_rcn",
        "ec_ci",
        "ee_ik",
        "eg_tin",
        "es_nif",
        "fi_hetu",
        "fr_nir",
        "gb_nino",
        "gh_pin",
        "gr_afm",
        "gt_nit",
        "gy_tin",
        "hk_id",
        "hn_rtn",
        "hr_oib",
        "hu_ad",
        "id_nik",
        "ie_ppsn",
        "is_kt",
        "it_cf",
        "jm_trn",
        "jo_pin",
        "jp_inc",
        "ke_pin",
        "ky_pp",
        "kz_iin",
        "li_peid",
        "lk_nic",
        "lt_ak",
        "lu_nif",
        "lv_pk",
        "mo_bir",
        "mt_nic",
        "mv_tin",
        "mx_rfc",
        "my_nric",
        "mz_nuit",
        "ng_nin",
        "nl_bsn",
        "no_nin",
        "nz_ird",
        "pa_ruc",
        "pe_dni",
        "ph_tin",
        "pk_cnic",
        "pk_snic",
        "pl_pesel",
        "pt_nif",
        "py_ruc",
        "ro_cnp",
        "sa_tin",
        "se_pin",
        "sg_fin",
        "sg_nric",
        "si_pin",
        "sk_dic",
        "sv_nit",
        "th_lc",
        "th_pin",
        "tr_tin",
        "us_itin",
        "us_itin_last_4",
        "us_ssn",
        "us_ssn_last_4",
        "uy_dni",
        "vg_pp",
        "za_id",
    ]
    """
    The ID number type of an individual.
    """
    value: str
    """
    The value of the ID number.
    """


class AccountTokenCreateParamsIdentityIndividualRelationship(TypedDict):
    director: NotRequired[bool]
    """
    Whether the person is a director of the account's identity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.
    """
    executive: NotRequired[bool]
    """
    Whether the person has significant responsibility to control, manage, or direct the organization.
    """
    owner: NotRequired[bool]
    """
    Whether the person is an owner of the account's identity.
    """
    percent_ownership: NotRequired[Decimal]
    """
    The percent owned by the person of the account's legal entity.
    """
    title: NotRequired[str]
    """
    The person's title (e.g., CEO, Support Engineer).
    """


class AccountTokenCreateParamsIdentityIndividualScriptAddresses(TypedDict):
    kana: NotRequired[
        "AccountTokenCreateParamsIdentityIndividualScriptAddressesKana"
    ]
    """
    Kana Address.
    """
    kanji: NotRequired[
        "AccountTokenCreateParamsIdentityIndividualScriptAddressesKanji"
    ]
    """
    Kanji Address.
    """


class AccountTokenCreateParamsIdentityIndividualScriptAddressesKana(TypedDict):
    city: NotRequired[str]
    """
    City, district, suburb, town, or village.
    """
    country: NotRequired[str]
    """
    Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
    """
    line1: NotRequired[str]
    """
    Address line 1 (e.g., street, PO Box, or company name).
    """
    line2: NotRequired[str]
    """
    Address line 2 (e.g., apartment, suite, unit, or building).
    """
    postal_code: NotRequired[str]
    """
    ZIP or postal code.
    """
    state: NotRequired[str]
    """
    State, county, province, or region.
    """
    town: NotRequired[str]
    """
    Town or district.
    """


class AccountTokenCreateParamsIdentityIndividualScriptAddressesKanji(
    TypedDict
):
    city: NotRequired[str]
    """
    City, district, suburb, town, or village.
    """
    country: NotRequired[str]
    """
    Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
    """
    line1: NotRequired[str]
    """
    Address line 1 (e.g., street, PO Box, or company name).
    """
    line2: NotRequired[str]
    """
    Address line 2 (e.g., apartment, suite, unit, or building).
    """
    postal_code: NotRequired[str]
    """
    ZIP or postal code.
    """
    state: NotRequired[str]
    """
    State, county, province, or region.
    """
    town: NotRequired[str]
    """
    Town or district.
    """


class AccountTokenCreateParamsIdentityIndividualScriptNames(TypedDict):
    kana: NotRequired[
        "AccountTokenCreateParamsIdentityIndividualScriptNamesKana"
    ]
    """
    Persons name in kana script.
    """
    kanji: NotRequired[
        "AccountTokenCreateParamsIdentityIndividualScriptNamesKanji"
    ]
    """
    Persons name in kanji script.
    """


class AccountTokenCreateParamsIdentityIndividualScriptNamesKana(TypedDict):
    given_name: NotRequired[str]
    """
    The person's first or given name.
    """
    surname: NotRequired[str]
    """
    The person's last or family name.
    """


class AccountTokenCreateParamsIdentityIndividualScriptNamesKanji(TypedDict):
    given_name: NotRequired[str]
    """
    The person's first or given name.
    """
    surname: NotRequired[str]
    """
    The person's last or family name.
    """



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._stripe_object import StripeObject
from typing import ClassVar, Optional
from typing_extensions import Literal


class PricingPlanVersion(StripeObject):
    """
    A Pricing Plan Version represents a specific configuration of a Pricing Plan at a point in time. Versions are created
    automatically when you update a Pricing Plan, allowing you to track changes and manage which version is active for new
    subscriptions. Each version has a start date and optionally an end date if it has been superseded.
    """

    OBJECT_NAME: ClassVar[Literal["v2.billing.pricing_plan_version"]] = (
        "v2.billing.pricing_plan_version"
    )
    created: str
    """
    Time at which the object was created.
    """
    end_date: Optional[str]
    """
    The timestamp when this version became inactive. null if it's the latest version.
    """
    id: str
    """
    Unique identifier for the object.
    """
    livemode: bool
    """
    Has the value `true` if the object exists in live mode or the value `false` if the object exists in test mode.
    """
    object: Literal["v2.billing.pricing_plan_version"]
    """
    String representing the object's type. Objects of the same type share the same value of the object field.
    """
    pricing_plan: str
    """
    The ID of the PricingPlan this version belongs to.
    """
    start_date: str
    """
    The timestamp when this version became active.
    """



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
import json
from stripe._api_version import _ApiVersion
from stripe._stripe_service import StripeService
from stripe._util import sanitize_id
from typing import Optional, cast
from uuid import uuid4
from typing_extensions import TYPE_CHECKING

if TYPE_CHECKING:
    from stripe._list_object import ListObject
    from stripe._request_options import RequestOptions
    from stripe.params.radar._value_list_item_create_params import (
        ValueListItemCreateParams,
    )
    from stripe.params.radar._value_list_item_delete_params import (
        ValueListItemDeleteParams,
    )
    from stripe.params.radar._value_list_item_list_params import (
        ValueListItemListParams,
    )
    from stripe.params.radar._value_list_item_retrieve_params import (
        ValueListItemRetrieveParams,
    )
    from stripe.radar._value_list_item import ValueListItem


class ValueListItemService(StripeService):
    def delete(
        self,
        item: str,
        params: Optional["ValueListItemDeleteParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "ValueListItem":
        """
        Deletes a ValueListItem object, removing it from its parent value list.
        """
        return cast(
            "ValueListItem",
            self._request(
                "delete",
                "/v1/radar/value_list_items/{item}".format(
                    item=sanitize_id(item),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def delete_async(
        self,
        item: str,
        params: Optional["ValueListItemDeleteParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "ValueListItem":
        """
        Deletes a ValueListItem object, removing it from its parent value list.
        """
        return cast(
            "ValueListItem",
            await self._request_async(
                "delete",
                "/v1/radar/value_list_items/{item}".format(
                    item=sanitize_id(item),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def retrieve(
        self,
        item: str,
        params: Optional["ValueListItemRetrieveParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "ValueListItem":
        """
        Retrieves a ValueListItem object.
        """
        return cast(
            "ValueListItem",
            self._request(
                "get",
                "/v1/radar/value_list_items/{item}".format(
                    item=sanitize_id(item),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def retrieve_async(
        self,
        item: str,
        params: Optional["ValueListItemRetrieveParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "ValueListItem":
        """
        Retrieves a ValueListItem object.
        """
        return cast(
            "ValueListItem",
            await self._request_async(
                "get",
                "/v1/radar/value_list_items/{item}".format(
                    item=sanitize_id(item),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def list(
        self,
        params: "ValueListItemListParams",
        options: Optional["RequestOptions"] = None,
    ) -> "ListObject[ValueListItem]":
        """
        Returns a list of ValueListItem objects. The objects are sorted in descending order by creation date, with the most recently created object appearing first.
        """
        return cast(
            "ListObject[ValueListItem]",
            self._request(
                "get",
                "/v1/radar/value_list_items",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def list_async(
        self,
        params: "ValueListItemListParams",
        options: Optional["RequestOptions"] = None,
    ) -> "ListObject[ValueListItem]":
        """
        Returns a list of ValueListItem objects. The objects are sorted in descending order by creation date, with the most recently created object appearing first.
        """
        return cast(
            "ListObject[ValueListItem]",
            await self._request_async(
                "get",
                "/v1/radar/value_list_items",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def create(
        self,
        params: "ValueListItemCreateParams",
        options: Optional["RequestOptions"] = None,
    ) -> "ValueListItem":
        """
        Creates a new ValueListItem object, which is added to the specified parent value list.
        """
        return cast(
            "ValueListItem",
            self._request(
                "post",
                "/v1/radar/value_list_items",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def create_async(
        self,
        params: "ValueListItemCreateParams",
        options: Optional["RequestOptions"] = None,
    ) -> "ValueListItem":
        """
        Creates a new ValueListItem object, which is added to the specified parent value list.
        """
        return cast(
            "ValueListItem",
            await self._request_async(
                "post",
                "/v1/radar/value_list_items",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def serialize_batch_create(
        self,
        params: Optional["ValueListItemCreateParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> str:
        """
        Serializes a ValueListItem create request into a batch job JSONL line.
        """
        item_id = str(uuid4())
        stripe_version = (
            options.get("stripe_version") if options else None
        ) or _ApiVersion.CURRENT
        context = options.get("stripe_context") if options else None
        batch_request = {
            "id": item_id,
            "params": params,
            "stripe_version": stripe_version,
        }
        if context is not None:
            batch_request["context"] = context
        return json.dumps(batch_request)



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._request_options import RequestOptions
from typing import List
from typing_extensions import Literal, NotRequired


class OnrampTransactionLimitsRetrieveParams(RequestOptions):
    customer_ip_address: NotRequired[str]
    """
    The IP address of the customer requesting transaction limits. We support IPv4 and IPv6 addresses.
    """
    destination_network: NotRequired[
        Literal[
            "avalanche",
            "base",
            "bitcoin",
            "ethereum",
            "optimism",
            "polygon",
            "solana",
            "stellar",
            "worldchain",
        ]
    ]
    """
    The destination blockchain network to use for limit calculations.
    """
    destination_tag: NotRequired[str]
    """
    The destination tag for the wallet address, if applicable for the network.
    """
    expand: NotRequired[List[str]]
    """
    Specifies which fields in the response should be expanded.
    """
    wallet_address: NotRequired[str]
    """
    The wallet address to use for destination-specific limit calculations.
    """



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._api_resource import APIResource
from stripe._list_object import ListObject
from stripe._stripe_object import StripeObject, UntypedStripeObject
from stripe._util import class_method_variant, sanitize_id
from typing import ClassVar, List, Optional, cast, overload
from typing_extensions import Literal, Unpack, TYPE_CHECKING

if TYPE_CHECKING:
    from stripe.params.tax._transaction_create_from_calculation_params import (
        TransactionCreateFromCalculationParams,
    )
    from stripe.params.tax._transaction_create_reversal_params import (
        TransactionCreateReversalParams,
    )
    from stripe.params.tax._transaction_list_line_items_params import (
        TransactionListLineItemsParams,
    )
    from stripe.params.tax._transaction_retrieve_params import (
        TransactionRetrieveParams,
    )
    from stripe.tax._transaction_line_item import TransactionLineItem


class Transaction(APIResource["Transaction"]):
    """
    A Tax Transaction records the tax collected from or refunded to your customer.

    Related guide: [Calculate tax in your custom payment flow](https://docs.stripe.com/tax/custom#tax-transaction)
    """

    OBJECT_NAME: ClassVar[Literal["tax.transaction"]] = "tax.transaction"

    class CustomerDetails(StripeObject):
        class Address(StripeObject):
            city: Optional[str]
            """
            City, district, suburb, town, or village.
            """
            country: str
            """
            Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
            """
            line1: Optional[str]
            """
            Address line 1, such as the street, PO Box, or company name.
            """
            line2: Optional[str]
            """
            Address line 2, such as the apartment, suite, unit, or building.
            """
            postal_code: Optional[str]
            """
            ZIP or postal code.
            """
            state: Optional[str]
            """
            State/province as an [ISO 3166-2](https://en.wikipedia.org/wiki/ISO_3166-2) subdivision code, without country prefix, such as "NY" or "TX".
            """

        class TaxId(StripeObject):
            type: Literal[
                "ad_nrt",
                "ae_trn",
                "al_tin",
                "am_tin",
                "ao_tin",
                "ar_cuit",
                "au_abn",
                "au_arn",
                "aw_tin",
                "az_tin",
                "ba_tin",
                "bb_tin",
                "bd_bin",
                "bf_ifu",
                "bg_uic",
                "bh_vat",
                "bj_ifu",
                "bo_tin",
                "br_cnpj",
                "br_cpf",
                "bs_tin",
                "by_tin",
                "ca_bn",
                "ca_gst_hst",
                "ca_pst_bc",
                "ca_pst_mb",
                "ca_pst_sk",
                "ca_qst",
                "cd_nif",
                "ch_uid",
                "ch_vat",
                "cl_tin",
                "cm_niu",
                "cn_tin",
                "co_nit",
                "cr_tin",
                "cv_nif",
                "de_stn",
                "do_rcn",
                "ec_ruc",
                "eg_tin",
                "es_cif",
                "et_tin",
                "eu_oss_vat",
                "eu_vat",
                "fo_vat",
                "gb_vat",
                "ge_vat",
                "gi_tin",
                "gn_nif",
                "hk_br",
                "hr_oib",
                "hu_tin",
                "id_npwp",
                "il_vat",
                "in_gst",
                "is_vat",
                "it_cf",
                "jp_cn",
                "jp_rn",
                "jp_trn",
                "ke_pin",
                "kg_tin",
                "kh_tin",
                "kr_brn",
                "kz_bin",
                "la_tin",
                "li_uid",
                "li_vat",
                "lk_vat",
                "ma_vat",
                "md_vat",
                "me_pib",
                "mk_vat",
                "mr_nif",
                "mx_rfc",
                "my_frp",
                "my_itn",
                "my_sst",
                "ng_tin",
                "no_vat",
                "no_voec",
                "np_pan",
                "nz_gst",
                "om_vat",
                "pe_ruc",
                "ph_tin",
                "pl_nip",
                "py_ruc",
                "ro_tin",
                "rs_pib",
                "ru_inn",
                "ru_kpp",
                "sa_vat",
                "sg_gst",
                "sg_uen",
                "si_tin",
                "sn_ninea",
                "sr_fin",
                "sv_nit",
                "th_vat",
                "tj_tin",
                "tr_tin",
                "tw_vat",
                "tz_vat",
                "ua_vat",
                "ug_tin",
                "unknown",
                "us_ein",
                "uy_ruc",
                "uz_tin",
                "uz_vat",
                "ve_rif",
                "vn_tin",
                "za_vat",
                "zm_tin",
                "zw_tin",
            ]
            """
            The type of the tax ID, one of `ad_nrt`, `ar_cuit`, `eu_vat`, `bo_tin`, `br_cnpj`, `br_cpf`, `cn_tin`, `co_nit`, `cr_tin`, `do_rcn`, `ec_ruc`, `eu_oss_vat`, `hr_oib`, `pe_ruc`, `ro_tin`, `rs_pib`, `sv_nit`, `uy_ruc`, `ve_rif`, `vn_tin`, `gb_vat`, `nz_gst`, `au_abn`, `au_arn`, `in_gst`, `no_vat`, `no_voec`, `za_vat`, `ch_vat`, `mx_rfc`, `sg_uen`, `ru_inn`, `ru_kpp`, `ca_bn`, `hk_br`, `es_cif`, `pl_nip`, `it_cf`, `fo_vat`, `gi_tin`, `py_ruc`, `tw_vat`, `th_vat`, `jp_cn`, `jp_rn`, `jp_trn`, `li_uid`, `li_vat`, `lk_vat`, `my_itn`, `us_ein`, `kr_brn`, `ca_qst`, `ca_gst_hst`, `ca_pst_bc`, `ca_pst_mb`, `ca_pst_sk`, `my_sst`, `sg_gst`, `ae_trn`, `cl_tin`, `sa_vat`, `id_npwp`, `my_frp`, `il_vat`, `ge_vat`, `ua_vat`, `is_vat`, `bg_uic`, `hu_tin`, `si_tin`, `ke_pin`, `tr_tin`, `eg_tin`, `ph_tin`, `al_tin`, `bh_vat`, `kz_bin`, `ng_tin`, `om_vat`, `de_stn`, `ch_uid`, `tz_vat`, `uz_vat`, `uz_tin`, `md_vat`, `ma_vat`, `by_tin`, `ao_tin`, `bs_tin`, `bb_tin`, `cd_nif`, `mr_nif`, `me_pib`, `zw_tin`, `ba_tin`, `gn_nif`, `mk_vat`, `sr_fin`, `sn_ninea`, `am_tin`, `np_pan`, `tj_tin`, `ug_tin`, `zm_tin`, `kh_tin`, `aw_tin`, `az_tin`, `bd_bin`, `bj_ifu`, `et_tin`, `kg_tin`, `la_tin`, `cm_niu`, `cv_nif`, `bf_ifu`, or `unknown`
            """
            value: str
            """
            The value of the tax ID.
            """

        address: Optional[Address]
        """
        The customer's postal address (for example, home or business location).
        """
        address_source: Optional[Literal["billing", "shipping"]]
        """
        The type of customer address provided.
        """
        ip_address: Optional[str]
        """
        The customer's IP address (IPv4 or IPv6).
        """
        tax_ids: List[TaxId]
        """
        The customer's tax IDs (for example, EU VAT numbers).
        """
        taxability_override: Literal[
            "customer_exempt", "none", "reverse_charge"
        ]
        """
        The taxability override used for taxation.
        """
        _inner_class_types = {"address": Address, "tax_ids": TaxId}

    class Reversal(StripeObject):
        original_transaction: Optional[str]
        """
        The `id` of the reversed `Transaction` object.
        """

    class ShipFromDetails(StripeObject):
        class Address(StripeObject):
            city: Optional[str]
            """
            City, district, suburb, town, or village.
            """
            country: str
            """
            Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
            """
            line1: Optional[str]
            """
            Address line 1, such as the street, PO Box, or company name.
            """
            line2: Optional[str]
            """
            Address line 2, such as the apartment, suite, unit, or building.
            """
            postal_code: Optional[str]
            """
            ZIP or postal code.
            """
            state: Optional[str]
            """
            State/province as an [ISO 3166-2](https://en.wikipedia.org/wiki/ISO_3166-2) subdivision code, without country prefix, such as "NY" or "TX".
            """

        address: Address
        _inner_class_types = {"address": Address}

    class ShippingCost(StripeObject):
        class TaxBreakdown(StripeObject):
            class Jurisdiction(StripeObject):
                country: str
                """
                Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
                """
                display_name: str
                """
                A human-readable name for the jurisdiction imposing the tax.
                """
                level: Literal[
                    "city", "country", "county", "district", "state"
                ]
                """
                Indicates the level of the jurisdiction imposing the tax.
                """
                state: Optional[str]
                """
                [ISO 3166-2 subdivision code](https://en.wikipedia.org/wiki/ISO_3166-2), without country prefix. For example, "NY" for New York, United States.
                """

            class TaxRateDetails(StripeObject):
                display_name: str
                """
                A localized display name for tax type, intended to be human-readable. For example, "Local Sales and Use Tax", "Value-added tax (VAT)", or "Umsatzsteuer (USt.)".
                """
                percentage_decimal: str
                """
                The tax rate percentage as a string. For example, 8.5% is represented as "8.5".
                """
                tax_type: Literal[
                    "admissions_tax",
                    "amusement_tax",
                    "attendance_tax",
                    "communications_tax",
                    "entertainment_tax",
                    "gross_receipts_tax",
                    "gst",
                    "hospitality_tax",
                    "hst",
                    "igst",
                    "jct",
                    "lease_tax",
                    "luxury_tax",
                    "pst",
                    "qst",
                    "resort_tax",
                    "retail_delivery_fee",
                    "rst",
                    "sales_tax",
                    "service_tax",
                    "tourism_tax",
                    "vat",
                ]
                """
                The tax type, such as `vat` or `sales_tax`.
                """

            amount: int
            """
            The amount of tax, in the [smallest currency unit](https://docs.stripe.com/currencies#minor-units).
            """
            jurisdiction: Jurisdiction
            sourcing: Literal["destination", "origin", "performance"]
            """
            Indicates whether the jurisdiction was determined by the origin (merchant's address) or destination (customer's address).
            """
            tax_rate_details: Optional[TaxRateDetails]
            """
            Details regarding the rate for this tax. This field will be `null` when the tax is not imposed, for example if the product is exempt from tax.
            """
            taxability_reason: Literal[
                "customer_exempt",
                "not_collecting",
                "not_subject_to_tax",
                "not_supported",
                "portion_product_exempt",
                "portion_reduced_rated",
                "portion_standard_rated",
                "product_exempt",
                "product_exempt_holiday",
                "proportionally_rated",
                "reduced_rated",
                "reverse_charge",
                "standard_rated",
                "taxable_basis_reduced",
                "zero_rated",
            ]
            """
            The reasoning behind this tax, for example, if the product is tax exempt. The possible values for this field may be extended as new tax rules are supported.
            """
            taxable_amount: int
            """
            The amount on which tax is calculated, in the [smallest currency unit](https://docs.stripe.com/currencies#minor-units).
            """
            _inner_class_types = {
                "jurisdiction": Jurisdiction,
                "tax_rate_details": TaxRateDetails,
            }

        amount: int
        """
        The shipping amount in the [smallest currency unit](https://docs.stripe.com/currencies#minor-units). If `tax_behavior=inclusive`, then this amount includes taxes. Otherwise, taxes were calculated on top of this amount.
        """
        amount_tax: int
        """
        The amount of tax calculated for shipping, in the [smallest currency unit](https://docs.stripe.com/currencies#minor-units).
        """
        shipping_rate: Optional[str]
        """
        The ID of an existing [ShippingRate](https://docs.stripe.com/api/shipping_rates/object).
        """
        tax_behavior: Literal["exclusive", "inclusive"]
        """
        Specifies whether the `amount` includes taxes. If `tax_behavior=inclusive`, then the amount includes taxes.
        """
        tax_breakdown: Optional[List[TaxBreakdown]]
        """
        Detailed account of taxes relevant to shipping cost. (It is not populated for the transaction resource object and will be removed in the next API version.)
        """
        tax_code: str
        """
        The [tax code](https://docs.stripe.com/tax/tax-categories) ID used for shipping.
        """
        _inner_class_types = {"tax_breakdown": TaxBreakdown}

    created: int
    """
    Time at which the object was created. Measured in seconds since the Unix epoch.
    """
    currency: str
    """
    Three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](https://stripe.com/docs/currencies).
    """
    customer: Optional[str]
    """
    The ID of an existing [Customer](https://docs.stripe.com/api/customers/object) used for the resource.
    """
    customer_details: CustomerDetails
    id: str
    """
    Unique identifier for the transaction.
    """
    line_items: Optional[ListObject["TransactionLineItem"]]
    """
    The tax collected or refunded, by line item.
    """
    livemode: bool
    """
    If the object exists in live mode, the value is `true`. If the object exists in test mode, the value is `false`.
    """
    metadata: Optional[UntypedStripeObject[str]]
    """
    Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
    """
    object: Literal["tax.transaction"]
    """
    String representing the object's type. Objects of the same type share the same value.
    """
    posted_at: int
    """
    The Unix timestamp representing when the tax liability is assumed or reduced.
    """
    reference: str
    """
    A custom unique identifier, such as 'myOrder_123'.
    """
    reversal: Optional[Reversal]
    """
    If `type=reversal`, contains information about what was reversed.
    """
    ship_from_details: Optional[ShipFromDetails]
    """
    The details of the ship from location, such as the address.
    """
    shipping_cost: Optional[ShippingCost]
    """
    The shipping cost details for the transaction.
    """
    tax_date: int
    """
    The calculation uses the tax rules and rates that are in effect at this timestamp. You can use a date up to 31 days in the past or up to 31 days in the future. If you use a future date, Stripe doesn't guarantee that the expected tax rules and rate being used match the actual rules and rate that will be in effect on that date. We deploy tax changes before their effective date, but not within a fixed window.
    """
    type: Literal["reversal", "transaction"]
    """
    If `reversal`, this transaction reverses an earlier transaction.
    """

    @classmethod
    def create_from_calculation(
        cls, **params: Unpack["TransactionCreateFromCalculationParams"]
    ) -> "Transaction":
        """
        Creates a Tax Transaction from a calculation, if that calculation hasn't expired. Calculations expire after 90 days.
        """
        return cast(
            "Transaction",
            cls._static_request(
                "post",
                "/v1/tax/transactions/create_from_calculation",
                params=params,
            ),
        )

    @classmethod
    async def create_from_calculation_async(
        cls, **params: Unpack["TransactionCreateFromCalculationParams"]
    ) -> "Transaction":
        """
        Creates a Tax Transaction from a calculation, if that calculation hasn't expired. Calculations expire after 90 days.
        """
        return cast(
            "Transaction",
            await cls._static_request_async(
                "post",
                "/v1/tax/transactions/create_from_calculation",
                params=params,
            ),
        )

    @classmethod
    def create_reversal(
        cls, **params: Unpack["TransactionCreateReversalParams"]
    ) -> "Transaction":
        """
        Partially or fully reverses a previously created Transaction.
        """
        return cast(
            "Transaction",
            cls._static_request(
                "post",
                "/v1/tax/transactions/create_reversal",
                params=params,
            ),
        )

    @classmethod
    async def create_reversal_async(
        cls, **params: Unpack["TransactionCreateReversalParams"]
    ) -> "Transaction":
        """
        Partially or fully reverses a previously created Transaction.
        """
        return cast(
            "Transaction",
            await cls._static_request_async(
                "post",
                "/v1/tax/transactions/create_reversal",
                params=params,
            ),
        )

    @classmethod
    def _cls_list_line_items(
        cls,
        transaction: str,
        **params: Unpack["TransactionListLineItemsParams"],
    ) -> ListObject["TransactionLineItem"]:
        """
        Retrieves the line items of a committed standalone transaction as a collection.
        """
        return cast(
            ListObject["TransactionLineItem"],
            cls._static_request(
                "get",
                "/v1/tax/transactions/{transaction}/line_items".format(
                    transaction=sanitize_id(transaction)
                ),
                params=params,
            ),
        )

    @overload
    @staticmethod
    def list_line_items(
        transaction: str, **params: Unpack["TransactionListLineItemsParams"]
    ) -> ListObject["TransactionLineItem"]:
        """
        Retrieves the line items of a committed standalone transaction as a collection.
        """
        ...

    @overload
    def list_line_items(
        self, **params: Unpack["TransactionListLineItemsParams"]
    ) -> ListObject["TransactionLineItem"]:
        """
        Retrieves the line items of a committed standalone transaction as a collection.
        """
        ...

    @class_method_variant("_cls_list_line_items")
    def list_line_items(  # pyright: ignore[reportGeneralTypeIssues]
        self, **params: Unpack["TransactionListLineItemsParams"]
    ) -> ListObject["TransactionLineItem"]:
        """
        Retrieves the line items of a committed standalone transaction as a collection.
        """
        return cast(
            ListObject["TransactionLineItem"],
            self._request(
                "get",
                "/v1/tax/transactions/{transaction}/line_items".format(
                    transaction=sanitize_id(self._data.get("id"))
                ),
                params=params,
            ),
        )

    @classmethod
    async def _cls_list_line_items_async(
        cls,
        transaction: str,
        **params: Unpack["TransactionListLineItemsParams"],
    ) -> ListObject["TransactionLineItem"]:
        """
        Retrieves the line items of a committed standalone transaction as a collection.
        """
        return cast(
            ListObject["TransactionLineItem"],
            await cls._static_request_async(
                "get",
                "/v1/tax/transactions/{transaction}/line_items".format(
                    transaction=sanitize_id(transaction)
                ),
                params=params,
            ),
        )

    @overload
    @staticmethod
    async def list_line_items_async(
        transaction: str, **params: Unpack["TransactionListLineItemsParams"]
    ) -> ListObject["TransactionLineItem"]:
        """
        Retrieves the line items of a committed standalone transaction as a collection.
        """
        ...

    @overload
    async def list_line_items_async(
        self, **params: Unpack["TransactionListLineItemsParams"]
    ) -> ListObject["TransactionLineItem"]:
        """
        Retrieves the line items of a committed standalone transaction as a collection.
        """
        ...

    @class_method_variant("_cls_list_line_items_async")
    async def list_line_items_async(  # pyright: ignore[reportGeneralTypeIssues]
        self, **params: Unpack["TransactionListLineItemsParams"]
    ) -> ListObject["TransactionLineItem"]:
        """
        Retrieves the line items of a committed standalone transaction as a collection.
        """
        return cast(
            ListObject["TransactionLineItem"],
            await self._request_async(
                "get",
                "/v1/tax/transactions/{transaction}/line_items".format(
                    transaction=sanitize_id(self._data.get("id"))
                ),
                params=params,
            ),
        )

    @classmethod
    def retrieve(
        cls, id: str, **params: Unpack["TransactionRetrieveParams"]
    ) -> "Transaction":
        """
        Retrieves a Tax Transaction object.
        """
        instance = cls(id, **params)
        instance.refresh()
        return instance

    @classmethod
    async def retrieve_async(
        cls, id: str, **params: Unpack["TransactionRetrieveParams"]
    ) -> "Transaction":
        """
        Retrieves a Tax Transaction object.
        """
        instance = cls(id, **params)
        await instance.refresh_async()
        return instance

    _inner_class_types = {
        "customer_details": CustomerDetails,
        "reversal": Reversal,
        "ship_from_details": ShipFromDetails,
        "shipping_cost": ShippingCost,
    }



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
import json
from stripe._api_version import _ApiVersion
from stripe._stripe_service import StripeService
from stripe._util import sanitize_id
from typing import Optional, cast
from uuid import uuid4
from typing_extensions import TYPE_CHECKING

if TYPE_CHECKING:
    from stripe._list_object import ListObject
    from stripe._request_options import RequestOptions
    from stripe._tax_rate import TaxRate
    from stripe.params._tax_rate_create_params import TaxRateCreateParams
    from stripe.params._tax_rate_list_params import TaxRateListParams
    from stripe.params._tax_rate_retrieve_params import TaxRateRetrieveParams
    from stripe.params._tax_rate_update_params import TaxRateUpdateParams


class TaxRateService(StripeService):
    def list(
        self,
        params: Optional["TaxRateListParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "ListObject[TaxRate]":
        """
        Returns a list of your tax rates. Tax rates are returned sorted by creation date, with the most recently created tax rates appearing first.
        """
        return cast(
            "ListObject[TaxRate]",
            self._request(
                "get",
                "/v1/tax_rates",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def list_async(
        self,
        params: Optional["TaxRateListParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "ListObject[TaxRate]":
        """
        Returns a list of your tax rates. Tax rates are returned sorted by creation date, with the most recently created tax rates appearing first.
        """
        return cast(
            "ListObject[TaxRate]",
            await self._request_async(
                "get",
                "/v1/tax_rates",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def create(
        self,
        params: "TaxRateCreateParams",
        options: Optional["RequestOptions"] = None,
    ) -> "TaxRate":
        """
        Creates a new tax rate.
        """
        return cast(
            "TaxRate",
            self._request(
                "post",
                "/v1/tax_rates",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def create_async(
        self,
        params: "TaxRateCreateParams",
        options: Optional["RequestOptions"] = None,
    ) -> "TaxRate":
        """
        Creates a new tax rate.
        """
        return cast(
            "TaxRate",
            await self._request_async(
                "post",
                "/v1/tax_rates",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def retrieve(
        self,
        tax_rate: str,
        params: Optional["TaxRateRetrieveParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "TaxRate":
        """
        Retrieves a tax rate with the given ID
        """
        return cast(
            "TaxRate",
            self._request(
                "get",
                "/v1/tax_rates/{tax_rate}".format(
                    tax_rate=sanitize_id(tax_rate),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def retrieve_async(
        self,
        tax_rate: str,
        params: Optional["TaxRateRetrieveParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "TaxRate":
        """
        Retrieves a tax rate with the given ID
        """
        return cast(
            "TaxRate",
            await self._request_async(
                "get",
                "/v1/tax_rates/{tax_rate}".format(
                    tax_rate=sanitize_id(tax_rate),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def update(
        self,
        tax_rate: str,
        params: Optional["TaxRateUpdateParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "TaxRate":
        """
        Updates an existing tax rate.
        """
        return cast(
            "TaxRate",
            self._request(
                "post",
                "/v1/tax_rates/{tax_rate}".format(
                    tax_rate=sanitize_id(tax_rate),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def update_async(
        self,
        tax_rate: str,
        params: Optional["TaxRateUpdateParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "TaxRate":
        """
        Updates an existing tax rate.
        """
        return cast(
            "TaxRate",
            await self._request_async(
                "post",
                "/v1/tax_rates/{tax_rate}".format(
                    tax_rate=sanitize_id(tax_rate),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def serialize_batch_create(
        self,
        params: Optional["TaxRateCreateParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> str:
        """
        Serializes a TaxRate create request into a batch job JSONL line.
        """
        item_id = str(uuid4())
        stripe_version = (
            options.get("stripe_version") if options else None
        ) or _ApiVersion.CURRENT
        context = options.get("stripe_context") if options else None
        batch_request = {
            "id": item_id,
            "params": params,
            "stripe_version": stripe_version,
        }
        if context is not None:
            batch_request["context"] = context
        return json.dumps(batch_request)

    def serialize_batch_update(
        self,
        tax_rate: str,
        params: Optional["TaxRateUpdateParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> str:
        """
        Serializes a TaxRate update request into a batch job JSONL line.
        """
        item_id = str(uuid4())
        stripe_version = (
            options.get("stripe_version") if options else None
        ) or _ApiVersion.CURRENT
        context = options.get("stripe_context") if options else None
        batch_request = {
            "id": item_id,
            "path_params": {"tax_rate": tax_rate},
            "params": params,
            "stripe_version": stripe_version,
        }
        if context is not None:
            batch_request["context"] = context
        return json.dumps(batch_request)



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._createable_api_resource import CreateableAPIResource
from stripe._list_object import ListObject
from stripe._listable_api_resource import ListableAPIResource
from stripe._stripe_object import StripeObject, UntypedStripeObject
from typing import ClassVar, Optional, cast
from typing_extensions import Literal, Unpack, TYPE_CHECKING

if TYPE_CHECKING:
    from stripe.params._fx_quote_create_params import FxQuoteCreateParams
    from stripe.params._fx_quote_list_params import FxQuoteListParams
    from stripe.params._fx_quote_retrieve_params import FxQuoteRetrieveParams


class FxQuote(
    CreateableAPIResource["FxQuote"], ListableAPIResource["FxQuote"]
):
    """
    The FX Quotes API provides three functions:
    - View Stripe's current exchange rate for any given currency pair.
    - Extend quoted rates for a 1-hour period or a 24-hour period, minimizing uncertainty from FX fluctuations.
    - Preview the FX fees Stripe will charge on your FX transaction, allowing you to anticipate specific settlement amounts before payment costs.

    [View the docs](https://docs.stripe.com/payments/currencies/localize-prices/fx-quotes-api)
    """

    OBJECT_NAME: ClassVar[Literal["fx_quote"]] = "fx_quote"

    class Rates(StripeObject):
        class RateDetails(StripeObject):
            base_rate: float
            """
            The rate for the currency pair.
            """
            duration_premium: float
            """
            The fee for locking the conversion rates.
            """
            fx_fee_rate: float
            """
            The FX fee for the currency pair.
            """
            reference_rate: Optional[float]
            """
            A reference rate for the currency pair provided by the reference rate provider.
            """
            reference_rate_provider: Optional[Literal["ecb"]]
            """
            The reference rate provider.
            """

        exchange_rate: float
        """
        The rate that includes the FX fee rate.
        """
        rate_details: RateDetails
        _inner_class_types = {"rate_details": RateDetails}

    class Usage(StripeObject):
        class Payment(StripeObject):
            destination: Optional[str]
            """
            The Stripe account ID that the funds will be transferred to.

            This field should match the account ID that would be used in the PaymentIntent's transfer_data[destination] field.
            """
            on_behalf_of: Optional[str]
            """
            The Stripe account ID that these funds are intended for.

            This field must match the account ID that would be used in the PaymentIntent's on_behalf_of field.
            """

        class Transfer(StripeObject):
            destination: str
            """
            The Stripe account ID that the funds will be transferred to.

            This field should match the account ID that would be used in the Transfer's destination field.
            """

        payment: Optional[Payment]
        """
        The details required to use an FX Quote for a payment
        """
        transfer: Optional[Transfer]
        """
        The details required to use an FX Quote for a transfer
        """
        type: Literal["payment", "transfer"]
        """
        The transaction type for which the FX Quote will be used.

        Can be 'payment' or 'transfer'.
        """
        _inner_class_types = {"payment": Payment, "transfer": Transfer}

    created: int
    """
    Time at which the quote was created, measured in seconds since the Unix epoch.
    """
    id: str
    """
    Unique identifier for the object.
    """
    lock_duration: Literal["day", "five_minutes", "hour", "none"]
    """
    The duration the exchange rate quote remains valid from creation time. Allowed values are none, hour, and day. Note that for the test mode API available in alpha, you can request an extended quote, but it won't be usable for any transactions.
    """
    lock_expires_at: Optional[int]
    """
    Time at which the quote will expire, measured in seconds since the Unix epoch.

    If lock_duration is set to ‘none' this field will be set to null.
    """
    lock_status: Literal["active", "expired", "none"]
    """
    Lock status of the quote. Transitions from active to expired once past the lock_expires_at timestamp.

    Can return value none, active, or expired.
    """
    object: Literal["fx_quote"]
    """
    String representing the object's type. Objects of the same type share the same value.
    """
    rates: UntypedStripeObject[Rates]
    """
    Information about the rates.
    """
    to_currency: str
    """
    The currency to convert into, typically this is the currency that you want to settle to your Stripe balance. Three-letter ISO currency code, in lowercase. Must be a supported currency.
    """
    usage: Usage

    @classmethod
    def create(cls, **params: Unpack["FxQuoteCreateParams"]) -> "FxQuote":
        """
        Creates an FX Quote object
        """
        return cast(
            "FxQuote",
            cls._static_request(
                "post",
                cls.class_url(),
                params=params,
            ),
        )

    @classmethod
    async def create_async(
        cls, **params: Unpack["FxQuoteCreateParams"]
    ) -> "FxQuote":
        """
        Creates an FX Quote object
        """
        return cast(
            "FxQuote",
            await cls._static_request_async(
                "post",
                cls.class_url(),
                params=params,
            ),
        )

    @classmethod
    def list(
        cls, **params: Unpack["FxQuoteListParams"]
    ) -> ListObject["FxQuote"]:
        """
        Returns a list of FX quotes that have been issued. The FX quotes are returned in sorted order, with the most recent FX quotes appearing first.
        """
        result = cls._static_request(
            "get",
            cls.class_url(),
            params=params,
        )
        if not isinstance(result, ListObject):
            raise TypeError(
                "Expected list object from API, got %s"
                % (type(result).__name__)
            )

        return result

    @classmethod
    async def list_async(
        cls, **params: Unpack["FxQuoteListParams"]
    ) -> ListObject["FxQuote"]:
        """
        Returns a list of FX quotes that have been issued. The FX quotes are returned in sorted order, with the most recent FX quotes appearing first.
        """
        result = await cls._static_request_async(
            "get",
            cls.class_url(),
            params=params,
        )
        if not isinstance(result, ListObject):
            raise TypeError(
                "Expected list object from API, got %s"
                % (type(result).__name__)
            )

        return result

    @classmethod
    def retrieve(
        cls, id: str, **params: Unpack["FxQuoteRetrieveParams"]
    ) -> "FxQuote":
        """
        Retrieve an FX Quote object
        """
        instance = cls(id, **params)
        instance.refresh()
        return instance

    @classmethod
    async def retrieve_async(
        cls, id: str, **params: Unpack["FxQuoteRetrieveParams"]
    ) -> "FxQuote":
        """
        Retrieve an FX Quote object
        """
        instance = cls(id, **params)
        await instance.refresh_async()
        return instance

    _inner_class_types = {"rates": Rates, "usage": Usage}



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from importlib import import_module
from typing_extensions import TYPE_CHECKING

if TYPE_CHECKING:
    from stripe.params.radar._account_evaluation_create_params import (
        AccountEvaluationCreateParams as AccountEvaluationCreateParams,
        AccountEvaluationCreateParamsLoginInitiated as AccountEvaluationCreateParamsLoginInitiated,
        AccountEvaluationCreateParamsLoginInitiatedClientDeviceMetadataDetails as AccountEvaluationCreateParamsLoginInitiatedClientDeviceMetadataDetails,
        AccountEvaluationCreateParamsLoginInitiatedClientDeviceMetadataDetailsData as AccountEvaluationCreateParamsLoginInitiatedClientDeviceMetadataDetailsData,
        AccountEvaluationCreateParamsRegistrationInitiated as AccountEvaluationCreateParamsRegistrationInitiated,
        AccountEvaluationCreateParamsRegistrationInitiatedClientDeviceMetadataDetails as AccountEvaluationCreateParamsRegistrationInitiatedClientDeviceMetadataDetails,
        AccountEvaluationCreateParamsRegistrationInitiatedClientDeviceMetadataDetailsData as AccountEvaluationCreateParamsRegistrationInitiatedClientDeviceMetadataDetailsData,
        AccountEvaluationCreateParamsRegistrationInitiatedCustomerData as AccountEvaluationCreateParamsRegistrationInitiatedCustomerData,
    )
    from stripe.params.radar._account_evaluation_modify_params import (
        AccountEvaluationModifyParams as AccountEvaluationModifyParams,
        AccountEvaluationModifyParamsLoginFailed as AccountEvaluationModifyParamsLoginFailed,
        AccountEvaluationModifyParamsLoginSucceeded as AccountEvaluationModifyParamsLoginSucceeded,
        AccountEvaluationModifyParamsRegistrationFailed as AccountEvaluationModifyParamsRegistrationFailed,
        AccountEvaluationModifyParamsRegistrationSucceeded as AccountEvaluationModifyParamsRegistrationSucceeded,
    )
    from stripe.params.radar._account_evaluation_retrieve_params import (
        AccountEvaluationRetrieveParams as AccountEvaluationRetrieveParams,
    )
    from stripe.params.radar._account_evaluation_update_params import (
        AccountEvaluationUpdateParams as AccountEvaluationUpdateParams,
        AccountEvaluationUpdateParamsLoginFailed as AccountEvaluationUpdateParamsLoginFailed,
        AccountEvaluationUpdateParamsLoginSucceeded as AccountEvaluationUpdateParamsLoginSucceeded,
        AccountEvaluationUpdateParamsRegistrationFailed as AccountEvaluationUpdateParamsRegistrationFailed,
        AccountEvaluationUpdateParamsRegistrationSucceeded as AccountEvaluationUpdateParamsRegistrationSucceeded,
    )
    from stripe.params.radar._customer_evaluation_create_params import (
        CustomerEvaluationCreateParams as CustomerEvaluationCreateParams,
        CustomerEvaluationCreateParamsEvaluationContext as CustomerEvaluationCreateParamsEvaluationContext,
        CustomerEvaluationCreateParamsEvaluationContextClientDetails as CustomerEvaluationCreateParamsEvaluationContextClientDetails,
        CustomerEvaluationCreateParamsEvaluationContextClientDetailsData as CustomerEvaluationCreateParamsEvaluationContextClientDetailsData,
        CustomerEvaluationCreateParamsEvaluationContextCustomerDetails as CustomerEvaluationCreateParamsEvaluationContextCustomerDetails,
        CustomerEvaluationCreateParamsEvaluationContextCustomerDetailsCustomerData as CustomerEvaluationCreateParamsEvaluationContextCustomerDetailsCustomerData,
    )
    from stripe.params.radar._customer_evaluation_modify_params import (
        CustomerEvaluationModifyParams as CustomerEvaluationModifyParams,
    )
    from stripe.params.radar._customer_evaluation_retrieve_params import (
        CustomerEvaluationRetrieveParams as CustomerEvaluationRetrieveParams,
    )
    from stripe.params.radar._customer_evaluation_update_params import (
        CustomerEvaluationUpdateParams as CustomerEvaluationUpdateParams,
    )
    from stripe.params.radar._early_fraud_warning_list_params import (
        EarlyFraudWarningListParams as EarlyFraudWarningListParams,
        EarlyFraudWarningListParamsCreated as EarlyFraudWarningListParamsCreated,
    )
    from stripe.params.radar._early_fraud_warning_retrieve_params import (
        EarlyFraudWarningRetrieveParams as EarlyFraudWarningRetrieveParams,
    )
    from stripe.params.radar._issuing_authorization_evaluation_create_params import (
        IssuingAuthorizationEvaluationCreateParams as IssuingAuthorizationEvaluationCreateParams,
        IssuingAuthorizationEvaluationCreateParamsAuthorizationDetails as IssuingAuthorizationEvaluationCreateParamsAuthorizationDetails,
        IssuingAuthorizationEvaluationCreateParamsCardDetails as IssuingAuthorizationEvaluationCreateParamsCardDetails,
        IssuingAuthorizationEvaluationCreateParamsCardholderDetails as IssuingAuthorizationEvaluationCreateParamsCardholderDetails,
        IssuingAuthorizationEvaluationCreateParamsMerchantDetails as IssuingAuthorizationEvaluationCreateParamsMerchantDetails,
        IssuingAuthorizationEvaluationCreateParamsNetworkDetails as IssuingAuthorizationEvaluationCreateParamsNetworkDetails,
        IssuingAuthorizationEvaluationCreateParamsTokenDetails as IssuingAuthorizationEvaluationCreateParamsTokenDetails,
        IssuingAuthorizationEvaluationCreateParamsVerificationDetails as IssuingAuthorizationEvaluationCreateParamsVerificationDetails,
    )
    from stripe.params.radar._payment_evaluation_create_params import (
        PaymentEvaluationCreateParams as PaymentEvaluationCreateParams,
        PaymentEvaluationCreateParamsClientDeviceMetadataDetails as PaymentEvaluationCreateParamsClientDeviceMetadataDetails,
        PaymentEvaluationCreateParamsClientDeviceMetadataDetailsData as PaymentEvaluationCreateParamsClientDeviceMetadataDetailsData,
        PaymentEvaluationCreateParamsCustomerDetails as PaymentEvaluationCreateParamsCustomerDetails,
        PaymentEvaluationCreateParamsPaymentDetails as PaymentEvaluationCreateParamsPaymentDetails,
        PaymentEvaluationCreateParamsPaymentDetailsMoneyMovementDetails as PaymentEvaluationCreateParamsPaymentDetailsMoneyMovementDetails,
        PaymentEvaluationCreateParamsPaymentDetailsMoneyMovementDetailsCard as PaymentEvaluationCreateParamsPaymentDetailsMoneyMovementDetailsCard,
        PaymentEvaluationCreateParamsPaymentDetailsPaymentMethodDetails as PaymentEvaluationCreateParamsPaymentDetailsPaymentMethodDetails,
        PaymentEvaluationCreateParamsPaymentDetailsPaymentMethodDetailsBillingDetails as PaymentEvaluationCreateParamsPaymentDetailsPaymentMethodDetailsBillingDetails,
        PaymentEvaluationCreateParamsPaymentDetailsPaymentMethodDetailsBillingDetailsAddress as PaymentEvaluationCreateParamsPaymentDetailsPaymentMethodDetailsBillingDetailsAddress,
        PaymentEvaluationCreateParamsPaymentDetailsShippingDetails as PaymentEvaluationCreateParamsPaymentDetailsShippingDetails,
        PaymentEvaluationCreateParamsPaymentDetailsShippingDetailsAddress as PaymentEvaluationCreateParamsPaymentDetailsShippingDetailsAddress,
    )
    from stripe.params.radar._value_list_create_params import (
        ValueListCreateParams as ValueListCreateParams,
    )
    from stripe.params.radar._value_list_delete_params import (
        ValueListDeleteParams as ValueListDeleteParams,
    )
    from stripe.params.radar._value_list_item_create_params import (
        ValueListItemCreateParams as ValueListItemCreateParams,
    )
    from stripe.params.radar._value_list_item_delete_params import (
        ValueListItemDeleteParams as ValueListItemDeleteParams,
    )
    from stripe.params.radar._value_list_item_list_params import (
        ValueListItemListParams as ValueListItemListParams,
        ValueListItemListParamsCreated as ValueListItemListParamsCreated,
    )
    from stripe.params.radar._value_list_item_retrieve_params import (
        ValueListItemRetrieveParams as ValueListItemRetrieveParams,
    )
    from stripe.params.radar._value_list_list_params import (
        ValueListListParams as ValueListListParams,
        ValueListListParamsCreated as ValueListListParamsCreated,
    )
    from stripe.params.radar._value_list_modify_params import (
        ValueListModifyParams as ValueListModifyParams,
    )
    from stripe.params.radar._value_list_retrieve_params import (
        ValueListRetrieveParams as ValueListRetrieveParams,
    )
    from stripe.params.radar._value_list_update_params import (
        ValueListUpdateParams as ValueListUpdateParams,
    )

# name -> (import_target, is_submodule)
_import_map = {
    "AccountEvaluationCreateParams": (
        "stripe.params.radar._account_evaluation_create_params",
        False,
    ),
    "AccountEvaluationCreateParamsLoginInitiated": (
        "stripe.params.radar._account_evaluation_create_params",
        False,
    ),
    "AccountEvaluationCreateParamsLoginInitiatedClientDeviceMetadataDetails": (
        "stripe.params.radar._account_evaluation_create_params",
        False,
    ),
    "AccountEvaluationCreateParamsLoginInitiatedClientDeviceMetadataDetailsData": (
        "stripe.params.radar._account_evaluation_create_params",
        False,
    ),
    "AccountEvaluationCreateParamsRegistrationInitiated": (
        "stripe.params.radar._account_evaluation_create_params",
        False,
    ),
    "AccountEvaluationCreateParamsRegistrationInitiatedClientDeviceMetadataDetails": (
        "stripe.params.radar._account_evaluation_create_params",
        False,
    ),
    "AccountEvaluationCreateParamsRegistrationInitiatedClientDeviceMetadataDetailsData": (
        "stripe.params.radar._account_evaluation_create_params",
        False,
    ),
    "AccountEvaluationCreateParamsRegistrationInitiatedCustomerData": (
        "stripe.params.radar._account_evaluation_create_params",
        False,
    ),
    "AccountEvaluationModifyParams": (
        "stripe.params.radar._account_evaluation_modify_params",
        False,
    ),
    "AccountEvaluationModifyParamsLoginFailed": (
        "stripe.params.radar._account_evaluation_modify_params",
        False,
    ),
    "AccountEvaluationModifyParamsLoginSucceeded": (
        "stripe.params.radar._account_evaluation_modify_params",
        False,
    ),
    "AccountEvaluationModifyParamsRegistrationFailed": (
        "stripe.params.radar._account_evaluation_modify_params",
        False,
    ),
    "AccountEvaluationModifyParamsRegistrationSucceeded": (
        "stripe.params.radar._account_evaluation_modify_params",
        False,
    ),
    "AccountEvaluationRetrieveParams": (
        "stripe.params.radar._account_evaluation_retrieve_params",
        False,
    ),
    "AccountEvaluationUpdateParams": (
        "stripe.params.radar._account_evaluation_update_params",
        False,
    ),
    "AccountEvaluationUpdateParamsLoginFailed": (
        "stripe.params.radar._account_evaluation_update_params",
        False,
    ),
    "AccountEvaluationUpdateParamsLoginSucceeded": (
        "stripe.params.radar._account_evaluation_update_params",
        False,
    ),
    "AccountEvaluationUpdateParamsRegistrationFailed": (
        "stripe.params.radar._account_evaluation_update_params",
        False,
    ),
    "AccountEvaluationUpdateParamsRegistrationSucceeded": (
        "stripe.params.radar._account_evaluation_update_params",
        False,
    ),
    "CustomerEvaluationCreateParams": (
        "stripe.params.radar._customer_evaluation_create_params",
        False,
    ),
    "CustomerEvaluationCreateParamsEvaluationContext": (
        "stripe.params.radar._customer_evaluation_create_params",
        False,
    ),
    "CustomerEvaluationCreateParamsEvaluationContextClientDetails": (
        "stripe.params.radar._customer_evaluation_create_params",
        False,
    ),
    "CustomerEvaluationCreateParamsEvaluationContextClientDetailsData": (
        "stripe.params.radar._customer_evaluation_create_params",
        False,
    ),
    "CustomerEvaluationCreateParamsEvaluationContextCustomerDetails": (
        "stripe.params.radar._customer_evaluation_create_params",
        False,
    ),
    "CustomerEvaluationCreateParamsEvaluationContextCustomerDetailsCustomerData": (
        "stripe.params.radar._customer_evaluation_create_params",
        False,
    ),
    "CustomerEvaluationModifyParams": (
        "stripe.params.radar._customer_evaluation_modify_params",
        False,
    ),
    "CustomerEvaluationRetrieveParams": (
        "stripe.params.radar._customer_evaluation_retrieve_params",
        False,
    ),
    "CustomerEvaluationUpdateParams": (
        "stripe.params.radar._customer_evaluation_update_params",
        False,
    ),
    "EarlyFraudWarningListParams": (
        "stripe.params.radar._early_fraud_warning_list_params",
        False,
    ),
    "EarlyFraudWarningListParamsCreated": (
        "stripe.params.radar._early_fraud_warning_list_params",
        False,
    ),
    "EarlyFraudWarningRetrieveParams": (
        "stripe.params.radar._early_fraud_warning_retrieve_params",
        False,
    ),
    "IssuingAuthorizationEvaluationCreateParams": (
        "stripe.params.radar._issuing_authorization_evaluation_create_params",
        False,
    ),
    "IssuingAuthorizationEvaluationCreateParamsAuthorizationDetails": (
        "stripe.params.radar._issuing_authorization_evaluation_create_params",
        False,
    ),
    "IssuingAuthorizationEvaluationCreateParamsCardDetails": (
        "stripe.params.radar._issuing_authorization_evaluation_create_params",
        False,
    ),
    "IssuingAuthorizationEvaluationCreateParamsCardholderDetails": (
        "stripe.params.radar._issuing_authorization_evaluation_create_params",
        False,
    ),
    "IssuingAuthorizationEvaluationCreateParamsMerchantDetails": (
        "stripe.params.radar._issuing_authorization_evaluation_create_params",
        False,
    ),
    "IssuingAuthorizationEvaluationCreateParamsNetworkDetails": (
        "stripe.params.radar._issuing_authorization_evaluation_create_params",
        False,
    ),
    "IssuingAuthorizationEvaluationCreateParamsTokenDetails": (
        "stripe.params.radar._issuing_authorization_evaluation_create_params",
        False,
    ),
    "IssuingAuthorizationEvaluationCreateParamsVerificationDetails": (
        "stripe.params.radar._issuing_authorization_evaluation_create_params",
        False,
    ),
    "PaymentEvaluationCreateParams": (
        "stripe.params.radar._payment_evaluation_create_params",
        False,
    ),
    "PaymentEvaluationCreateParamsClientDeviceMetadataDetails": (
        "stripe.params.radar._payment_evaluation_create_params",
        False,
    ),
    "PaymentEvaluationCreateParamsClientDeviceMetadataDetailsData": (
        "stripe.params.radar._payment_evaluation_create_params",
        False,
    ),
    "PaymentEvaluationCreateParamsCustomerDetails": (
        "stripe.params.radar._payment_evaluation_create_params",
        False,
    ),
    "PaymentEvaluationCreateParamsPaymentDetails": (
        "stripe.params.radar._payment_evaluation_create_params",
        False,
    ),
    "PaymentEvaluationCreateParamsPaymentDetailsMoneyMovementDetails": (
        "stripe.params.radar._payment_evaluation_create_params",
        False,
    ),
    "PaymentEvaluationCreateParamsPaymentDetailsMoneyMovementDetailsCard": (
        "stripe.params.radar._payment_evaluation_create_params",
        False,
    ),
    "PaymentEvaluationCreateParamsPaymentDetailsPaymentMethodDetails": (
        "stripe.params.radar._payment_evaluation_create_params",
        False,
    ),
    "PaymentEvaluationCreateParamsPaymentDetailsPaymentMethodDetailsBillingDetails": (
        "stripe.params.radar._payment_evaluation_create_params",
        False,
    ),
    "PaymentEvaluationCreateParamsPaymentDetailsPaymentMethodDetailsBillingDetailsAddress": (
        "stripe.params.radar._payment_evaluation_create_params",
        False,
    ),
    "PaymentEvaluationCreateParamsPaymentDetailsShippingDetails": (
        "stripe.params.radar._payment_evaluation_create_params",
        False,
    ),
    "PaymentEvaluationCreateParamsPaymentDetailsShippingDetailsAddress": (
        "stripe.params.radar._payment_evaluation_create_params",
        False,
    ),
    "ValueListCreateParams": (
        "stripe.params.radar._value_list_create_params",
        False,
    ),
    "ValueListDeleteParams": (
        "stripe.params.radar._value_list_delete_params",
        False,
    ),
    "ValueListItemCreateParams": (
        "stripe.params.radar._value_list_item_create_params",
        False,
    ),
    "ValueListItemDeleteParams": (
        "stripe.params.radar._value_list_item_delete_params",
        False,
    ),
    "ValueListItemListParams": (
        "stripe.params.radar._value_list_item_list_params",
        False,
    ),
    "ValueListItemListParamsCreated": (
        "stripe.params.radar._value_list_item_list_params",
        False,
    ),
    "ValueListItemRetrieveParams": (
        "stripe.params.radar._value_list_item_retrieve_params",
        False,
    ),
    "ValueListListParams": (
        "stripe.params.radar._value_list_list_params",
        False,
    ),
    "ValueListListParamsCreated": (
        "stripe.params.radar._value_list_list_params",
        False,
    ),
    "ValueListModifyParams": (
        "stripe.params.radar._value_list_modify_params",
        False,
    ),
    "ValueListRetrieveParams": (
        "stripe.params.radar._value_list_retrieve_params",
        False,
    ),
    "ValueListUpdateParams": (
        "stripe.params.radar._value_list_update_params",
        False,
    ),
}
if not TYPE_CHECKING:

    def __getattr__(name):
        try:
            target, is_submodule = _import_map[name]
            module = import_module(target)
            if is_submodule:
                return module

            return getattr(
                module,
                name,
            )
        except KeyError:
            raise AttributeError()



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from importlib import import_module
from typing_extensions import TYPE_CHECKING

if TYPE_CHECKING:
    from stripe.v2.money_management import (
        financial_accounts as financial_accounts,
        test_helpers as test_helpers,
    )
    from stripe.v2.money_management._adjustment import Adjustment as Adjustment
    from stripe.v2.money_management._adjustment_service import (
        AdjustmentService as AdjustmentService,
    )
    from stripe.v2.money_management._currency_conversion import (
        CurrencyConversion as CurrencyConversion,
    )
    from stripe.v2.money_management._currency_conversion_service import (
        CurrencyConversionService as CurrencyConversionService,
    )
    from stripe.v2.money_management._debit_dispute import (
        DebitDispute as DebitDispute,
    )
    from stripe.v2.money_management._debit_dispute_service import (
        DebitDisputeService as DebitDisputeService,
    )
    from stripe.v2.money_management._financial_account import (
        FinancialAccount as FinancialAccount,
    )
    from stripe.v2.money_management._financial_account_service import (
        FinancialAccountService as FinancialAccountService,
    )
    from stripe.v2.money_management._financial_account_statement import (
        FinancialAccountStatement as FinancialAccountStatement,
    )
    from stripe.v2.money_management._financial_address import (
        FinancialAddress as FinancialAddress,
    )
    from stripe.v2.money_management._financial_address_debit_simulation import (
        FinancialAddressDebitSimulation as FinancialAddressDebitSimulation,
    )
    from stripe.v2.money_management._financial_address_service import (
        FinancialAddressService as FinancialAddressService,
    )
    from stripe.v2.money_management._inbound_transfer import (
        InboundTransfer as InboundTransfer,
    )
    from stripe.v2.money_management._inbound_transfer_service import (
        InboundTransferService as InboundTransferService,
    )
    from stripe.v2.money_management._outbound_payment import (
        OutboundPayment as OutboundPayment,
    )
    from stripe.v2.money_management._outbound_payment_quote import (
        OutboundPaymentQuote as OutboundPaymentQuote,
    )
    from stripe.v2.money_management._outbound_payment_quote_service import (
        OutboundPaymentQuoteService as OutboundPaymentQuoteService,
    )
    from stripe.v2.money_management._outbound_payment_service import (
        OutboundPaymentService as OutboundPaymentService,
    )
    from stripe.v2.money_management._outbound_setup_intent import (
        OutboundSetupIntent as OutboundSetupIntent,
    )
    from stripe.v2.money_management._outbound_setup_intent_service import (
        OutboundSetupIntentService as OutboundSetupIntentService,
    )
    from stripe.v2.money_management._outbound_transfer import (
        OutboundTransfer as OutboundTransfer,
    )
    from stripe.v2.money_management._outbound_transfer_service import (
        OutboundTransferService as OutboundTransferService,
    )
    from stripe.v2.money_management._payout_intent import (
        PayoutIntent as PayoutIntent,
    )
    from stripe.v2.money_management._payout_intent_service import (
        PayoutIntentService as PayoutIntentService,
    )
    from stripe.v2.money_management._payout_method import (
        PayoutMethod as PayoutMethod,
    )
    from stripe.v2.money_management._payout_method_service import (
        PayoutMethodService as PayoutMethodService,
    )
    from stripe.v2.money_management._payout_methods_bank_account_spec import (
        PayoutMethodsBankAccountSpec as PayoutMethodsBankAccountSpec,
    )
    from stripe.v2.money_management._payout_methods_bank_account_spec_service import (
        PayoutMethodsBankAccountSpecService as PayoutMethodsBankAccountSpecService,
    )
    from stripe.v2.money_management._received_credit import (
        ReceivedCredit as ReceivedCredit,
    )
    from stripe.v2.money_management._received_credit_service import (
        ReceivedCreditService as ReceivedCreditService,
    )
    from stripe.v2.money_management._received_debit import (
        ReceivedDebit as ReceivedDebit,
    )
    from stripe.v2.money_management._received_debit_service import (
        ReceivedDebitService as ReceivedDebitService,
    )
    from stripe.v2.money_management._recipient_verification import (
        RecipientVerification as RecipientVerification,
    )
    from stripe.v2.money_management._recipient_verification_service import (
        RecipientVerificationService as RecipientVerificationService,
    )
    from stripe.v2.money_management._test_helpers_service import (
        TestHelpersService as TestHelpersService,
    )
    from stripe.v2.money_management._transaction import (
        Transaction as Transaction,
    )
    from stripe.v2.money_management._transaction_entry import (
        TransactionEntry as TransactionEntry,
    )
    from stripe.v2.money_management._transaction_entry_service import (
        TransactionEntryService as TransactionEntryService,
    )
    from stripe.v2.money_management._transaction_service import (
        TransactionService as TransactionService,
    )

# name -> (import_target, is_submodule)
_import_map = {
    "financial_accounts": (
        "stripe.v2.money_management.financial_accounts",
        True,
    ),
    "test_helpers": ("stripe.v2.money_management.test_helpers", True),
    "Adjustment": ("stripe.v2.money_management._adjustment", False),
    "AdjustmentService": (
        "stripe.v2.money_management._adjustment_service",
        False,
    ),
    "CurrencyConversion": (
        "stripe.v2.money_management._currency_conversion",
        False,
    ),
    "CurrencyConversionService": (
        "stripe.v2.money_management._currency_conversion_service",
        False,
    ),
    "DebitDispute": ("stripe.v2.money_management._debit_dispute", False),
    "DebitDisputeService": (
        "stripe.v2.money_management._debit_dispute_service",
        False,
    ),
    "FinancialAccount": (
        "stripe.v2.money_management._financial_account",
        False,
    ),
    "FinancialAccountService": (
        "stripe.v2.money_management._financial_account_service",
        False,
    ),
    "FinancialAccountStatement": (
        "stripe.v2.money_management._financial_account_statement",
        False,
    ),
    "FinancialAddress": (
        "stripe.v2.money_management._financial_address",
        False,
    ),
    "FinancialAddressDebitSimulation": (
        "stripe.v2.money_management._financial_address_debit_simulation",
        False,
    ),
    "FinancialAddressService": (
        "stripe.v2.money_management._financial_address_service",
        False,
    ),
    "InboundTransfer": ("stripe.v2.money_management._inbound_transfer", False),
    "InboundTransferService": (
        "stripe.v2.money_management._inbound_transfer_service",
        False,
    ),
    "OutboundPayment": ("stripe.v2.money_management._outbound_payment", False),
    "OutboundPaymentQuote": (
        "stripe.v2.money_management._outbound_payment_quote",
        False,
    ),
    "OutboundPaymentQuoteService": (
        "stripe.v2.money_management._outbound_payment_quote_service",
        False,
    ),
    "OutboundPaymentService": (
        "stripe.v2.money_management._outbound_payment_service",
        False,
    ),
    "OutboundSetupIntent": (
        "stripe.v2.money_management._outbound_setup_intent",
        False,
    ),
    "OutboundSetupIntentService": (
        "stripe.v2.money_management._outbound_setup_intent_service",
        False,
    ),
    "OutboundTransfer": (
        "stripe.v2.money_management._outbound_transfer",
        False,
    ),
    "OutboundTransferService": (
        "stripe.v2.money_management._outbound_transfer_service",
        False,
    ),
    "PayoutIntent": ("stripe.v2.money_management._payout_intent", False),
    "PayoutIntentService": (
        "stripe.v2.money_management._payout_intent_service",
        False,
    ),
    "PayoutMethod": ("stripe.v2.money_management._payout_method", False),
    "PayoutMethodService": (
        "stripe.v2.money_management._payout_method_service",
        False,
    ),
    "PayoutMethodsBankAccountSpec": (
        "stripe.v2.money_management._payout_methods_bank_account_spec",
        False,
    ),
    "PayoutMethodsBankAccountSpecService": (
        "stripe.v2.money_management._payout_methods_bank_account_spec_service",
        False,
    ),
    "ReceivedCredit": ("stripe.v2.money_management._received_credit", False),
    "ReceivedCreditService": (
        "stripe.v2.money_management._received_credit_service",
        False,
    ),
    "ReceivedDebit": ("stripe.v2.money_management._received_debit", False),
    "ReceivedDebitService": (
        "stripe.v2.money_management._received_debit_service",
        False,
    ),
    "RecipientVerification": (
        "stripe.v2.money_management._recipient_verification",
        False,
    ),
    "RecipientVerificationService": (
        "stripe.v2.money_management._recipient_verification_service",
        False,
    ),
    "TestHelpersService": (
        "stripe.v2.money_management._test_helpers_service",
        False,
    ),
    "Transaction": ("stripe.v2.money_management._transaction", False),
    "TransactionEntry": (
        "stripe.v2.money_management._transaction_entry",
        False,
    ),
    "TransactionEntryService": (
        "stripe.v2.money_management._transaction_entry_service",
        False,
    ),
    "TransactionService": (
        "stripe.v2.money_management._transaction_service",
        False,
    ),
}
if not TYPE_CHECKING:

    def __getattr__(name):
        try:
            target, is_submodule = _import_map[name]
            module = import_module(target)
            if is_submodule:
                return module

            return getattr(
                module,
                name,
            )
        except KeyError:
            raise AttributeError()



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._createable_api_resource import CreateableAPIResource
from stripe._stripe_object import StripeObject, UntypedStripeObject
from typing import ClassVar, Optional, cast
from typing_extensions import Literal, Unpack, TYPE_CHECKING

if TYPE_CHECKING:
    from stripe.params.radar._issuing_authorization_evaluation_create_params import (
        IssuingAuthorizationEvaluationCreateParams,
    )


class IssuingAuthorizationEvaluation(
    CreateableAPIResource["IssuingAuthorizationEvaluation"],
):
    """
    Authorization Evaluations represent fraud risk assessments for Issuing card authorizations. They include fraud risk signals and contextual details about the authorization.
    """

    OBJECT_NAME: ClassVar[
        Literal["radar.issuing_authorization_evaluation"]
    ] = "radar.issuing_authorization_evaluation"

    class AuthorizationDetails(StripeObject):
        amount: int
        """
        The total amount of the authorization in the [smallest currency unit](https://stripe.com/docs/currencies#zero-decimal).
        """
        authorization_method: Optional[
            Literal["chip", "contactless", "keyed_in", "online", "swipe"]
        ]
        """
        How the card details were provided.
        """
        currency: str
        """
        Three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](https://stripe.com/docs/currencies).
        """
        entry_mode: Optional[
            Literal[
                "contactless",
                "contactless_magstripe",
                "credential_on_file",
                "integrated_circuit_card",
                "magstripe",
                "magstripe_no_cvv",
                "manual",
                "other",
                "unknown",
            ]
        ]
        """
        Defines how the card's information was entered for the authorization.
        """
        entry_mode_raw_code: Optional[str]
        """
        Raw code indicating the entry mode from the network message.
        """
        initiated_at: int
        """
        The time the authorization was initiated, as a Unix timestamp in seconds.
        """
        point_of_sale_condition: Optional[
            Literal[
                "account_verification",
                "card_not_present",
                "card_present",
                "e_commerce",
                "key_entered_pos",
                "missing",
                "moto",
                "other",
                "pin_entered",
                "recurring",
            ]
        ]
        """
        Defines how the card was read at the point of sale.
        """
        point_of_sale_condition_raw_code: Optional[str]
        """
        Raw code indicating the point of sale condition from the network message.
        """
        reference: str
        """
        User's specified unique ID for this authorization attempt (e.g., RRN or internal reference).
        """

    class CardDetails(StripeObject):
        bin: str
        """
        The Bank Identification Number (BIN) of the card.
        """
        bin_country: str
        """
        The two-letter country code of the BIN issuer.
        """
        card_type: Literal["physical", "virtual"]
        """
        The type of the card.
        """
        created_at: int
        """
        The timestamp when the card was created, as a Unix timestamp in seconds.
        """
        last4: str
        """
        The last 4 digits of the card number.
        """
        reference: str
        """
        User's specified unique ID of the card for this authorization attempt (e.g., RRN or internal reference).
        """

    class CardholderDetails(StripeObject):
        created_at: Optional[int]
        """
        The timestamp when the cardholder was created.
        """
        reference: Optional[str]
        """
        User's specified unique ID of the cardholder for this authorization attempt (e.g., RRN or internal reference).
        """

    class MerchantDetails(StripeObject):
        category_code: str
        """
        The merchant category code for the seller's business.
        """
        country: Optional[str]
        """
        Country where the seller is located.
        """
        name: str
        """
        Name of the seller.
        """
        network_id: str
        """
        Identifier assigned to the seller by the card network. Different card networks may assign different network_id fields to the same merchant.
        """
        terminal_id: Optional[str]
        """
        An ID assigned by the seller to the location of the sale.
        """

    class NetworkDetails(StripeObject):
        acquiring_institution_id: Optional[str]
        """
        Identifier assigned to the acquirer by the card network. Sometimes this value is not provided by the network; in this case, the value will be null.
        """
        routed_network: Optional[
            Literal[
                "cirrus",
                "interlink",
                "maestro",
                "mastercard",
                "other",
                "plus",
                "visa",
            ]
        ]
        """
        The card network over which Stripe received the authorization.
        """

    class Signals(StripeObject):
        class FraudRisk(StripeObject):
            class Data(StripeObject):
                evaluated_at: int
                """
                The time when this signal was evaluated.
                """
                level: Literal[
                    "elevated",
                    "highest",
                    "low",
                    "normal",
                    "not_assessed",
                    "unknown",
                ]
                """
                Risk level, based on the score.
                """
                score: float
                """
                Fraud risk score for this evaluation. Score in the range [0,100], formatted as a 2 decimal float, with higher scores indicating a higher likelihood of fraud.
                """

            data: Optional[Data]
            """
            Signal evaluation data, including score and level.
            """
            error: Optional[UntypedStripeObject[str]]
            """
            Details of an error that prevented reporting this signal.
            """
            status: Literal["error", "success"]
            """
            The status of this signal.
            """
            _inner_class_types = {"data": Data}

        fraud_risk: FraudRisk
        """
        A fraud risk signal with status, error, and data fields.
        """
        _inner_class_types = {"fraud_risk": FraudRisk}

    class TokenDetails(StripeObject):
        created_at: Optional[int]
        """
        The timestamp when the network token was created.
        """
        reference: Optional[str]
        """
        User's specified unique ID of the card token for this authorization attempt (e.g., RRN or internal reference).
        """
        wallet: Optional[Literal["apple_pay", "google_pay", "samsung_pay"]]
        """
        The digital wallet used for this transaction. One of `apple_pay`, `google_pay`, or `samsung_pay`.
        """

    class VerificationDetails(StripeObject):
        three_d_secure_result: Optional[
            Literal[
                "attempt_acknowledged",
                "authenticated",
                "exempted",
                "failed",
                "required",
            ]
        ]
        """
        The outcome of the 3D Secure authentication request.
        """

    authorization_details: Optional[AuthorizationDetails]
    """
    Details about the authorization.
    """
    card_details: Optional[CardDetails]
    """
    Details about the card used in the authorization.
    """
    cardholder_details: Optional[CardholderDetails]
    """
    Details about the cardholder.
    """
    id: str
    """
    Unique identifier for the object.
    """
    livemode: bool
    """
    If the object exists in live mode, the value is `true`. If the object exists in test mode, the value is `false`.
    """
    merchant_details: Optional[MerchantDetails]
    """
    Details about the seller (grocery store, e-commerce website, etc.) where the card authorization happened.
    """
    metadata: Optional[UntypedStripeObject[str]]
    """
    Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
    """
    network_details: Optional[NetworkDetails]
    """
    Details about the authorization, such as identifiers, set by the card network.
    """
    object: Literal["radar.issuing_authorization_evaluation"]
    """
    String representing the object's type. Objects of the same type share the same value.
    """
    signals: Signals
    """
    Collection of fraud risk signals for this authorization evaluation.
    """
    token_details: Optional[TokenDetails]
    """
    Details about the token, if a tokenized payment method was used for the authorization.
    """
    verification_details: Optional[VerificationDetails]
    """
    Details about verification data for the authorization.
    """

    @classmethod
    def create(
        cls, **params: Unpack["IssuingAuthorizationEvaluationCreateParams"]
    ) -> "IssuingAuthorizationEvaluation":
        """
        Request a fraud risk assessment from Stripe for an Issuing card authorization.
        """
        return cast(
            "IssuingAuthorizationEvaluation",
            cls._static_request(
                "post",
                cls.class_url(),
                params=params,
            ),
        )

    @classmethod
    async def create_async(
        cls, **params: Unpack["IssuingAuthorizationEvaluationCreateParams"]
    ) -> "IssuingAuthorizationEvaluation":
        """
        Request a fraud risk assessment from Stripe for an Issuing card authorization.
        """
        return cast(
            "IssuingAuthorizationEvaluation",
            await cls._static_request_async(
                "post",
                cls.class_url(),
                params=params,
            ),
        )

    _inner_class_types = {
        "authorization_details": AuthorizationDetails,
        "card_details": CardDetails,
        "cardholder_details": CardholderDetails,
        "merchant_details": MerchantDetails,
        "network_details": NetworkDetails,
        "signals": Signals,
        "token_details": TokenDetails,
        "verification_details": VerificationDetails,
    }



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._stripe_service import StripeService
from importlib import import_module
from typing_extensions import TYPE_CHECKING

if TYPE_CHECKING:
    from stripe.test_helpers.treasury._inbound_transfer_service import (
        InboundTransferService,
    )
    from stripe.test_helpers.treasury._outbound_payment_service import (
        OutboundPaymentService,
    )
    from stripe.test_helpers.treasury._outbound_transfer_service import (
        OutboundTransferService,
    )
    from stripe.test_helpers.treasury._received_credit_service import (
        ReceivedCreditService,
    )
    from stripe.test_helpers.treasury._received_debit_service import (
        ReceivedDebitService,
    )

_subservices = {
    "inbound_transfers": [
        "stripe.test_helpers.treasury._inbound_transfer_service",
        "InboundTransferService",
    ],
    "outbound_payments": [
        "stripe.test_helpers.treasury._outbound_payment_service",
        "OutboundPaymentService",
    ],
    "outbound_transfers": [
        "stripe.test_helpers.treasury._outbound_transfer_service",
        "OutboundTransferService",
    ],
    "received_credits": [
        "stripe.test_helpers.treasury._received_credit_service",
        "ReceivedCreditService",
    ],
    "received_debits": [
        "stripe.test_helpers.treasury._received_debit_service",
        "ReceivedDebitService",
    ],
}


class TreasuryService(StripeService):
    inbound_transfers: "InboundTransferService"
    outbound_payments: "OutboundPaymentService"
    outbound_transfers: "OutboundTransferService"
    received_credits: "ReceivedCreditService"
    received_debits: "ReceivedDebitService"

    def __init__(self, requestor):
        super().__init__(requestor)

    def __getattr__(self, name):
        try:
            import_from, service = _subservices[name]
            service_class = getattr(
                import_module(import_from),
                service,
            )
            setattr(
                self,
                name,
                service_class(self._requestor),
            )
            return getattr(self, name)
        except KeyError:
            raise AttributeError()



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from typing_extensions import NotRequired, TypedDict


class FeeBatchListParams(TypedDict):
    collection_record: NotRequired[str]
    """
    Filter to return only FeeBatches associated with this collection record ID.
    """
    created: NotRequired[str]
    """
    Filter for FeeBatches created at the exact specified timestamp.
    """
    created_gt: NotRequired[str]
    """
    Filter for FeeBatches created after the specified timestamp (exclusive).
    """
    created_gte: NotRequired[str]
    """
    Filter for FeeBatches created at or after the specified timestamp (inclusive).
    """
    created_lt: NotRequired[str]
    """
    Filter for FeeBatches created before the specified timestamp (exclusive).
    """
    created_lte: NotRequired[str]
    """
    Filter for FeeBatches created at or before the specified timestamp (inclusive).
    """
    limit: NotRequired[int]
    """
    Maximum number of results to return per page. Defaults to 20.
    """



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._stripe_object import StripeObject
from typing import ClassVar, List, Optional
from typing_extensions import Literal


class ActivityLog(StripeObject):
    """
    An activity log records a single action performed on an account.
    """

    OBJECT_NAME: ClassVar[Literal["v2.iam.activity_log"]] = (
        "v2.iam.activity_log"
    )

    class Actor(StripeObject):
        class ApiKey(StripeObject):
            id: str
            """
            Unique identifier of the API key.
            """

        class User(StripeObject):
            email: str
            """
            Email address of the user.
            """

        api_key: Optional[ApiKey]
        """
        Set when the actor is an API key.
        """
        type: Literal["api_key", "user"]
        """
        The type of actor.
        """
        user: Optional[User]
        """
        Set when the actor is a user.
        """
        _inner_class_types = {"api_key": ApiKey, "user": User}

    class Details(StripeObject):
        class ApiKey(StripeObject):
            class ManagedBy(StripeObject):
                class Application(StripeObject):
                    id: str
                    """
                    Identifier of the application.
                    """

                application: Optional[Application]
                """
                An application.
                """
                type: Literal["application"]
                """
                The type of entity.
                """
                _inner_class_types = {"application": Application}

            created: str
            """
            Timestamp when the API key was created.
            """
            expires_at: Optional[str]
            """
            Timestamp when the API key expires.
            """
            id: str
            """
            Unique identifier of the API key.
            """
            ip_allowlist: List[str]
            """
            List of IP addresses allowed to use this API key.
            """
            managed_by: Optional[ManagedBy]
            """
            Information about the entity managing this API key.
            """
            name: Optional[str]
            """
            Name of the API key.
            """
            new_key: Optional[str]
            """
            Unique identifier of the new API key, set when this key was rotated.
            """
            note: Optional[str]
            """
            Note or description for the API key.
            """
            type: Literal["publishable_key", "secret_key"]
            """
            Type of the API key.
            """
            _inner_class_types = {"managed_by": ManagedBy}

        class UserInvite(StripeObject):
            invited_user_email: str
            """
            Email address of the invited user.
            """
            roles: List[str]
            """
            Roles assigned to the invited user.
            """

        class UserRoles(StripeObject):
            new_roles: List[str]
            """
            Roles the user has after the change.
            """
            old_roles: List[str]
            """
            Roles the user had before the change.
            """
            user_email: str
            """
            Email address of the user whose roles were changed.
            """

        api_key: Optional[ApiKey]
        """
        Details of an API key action.
        """
        type: Literal["api_key", "user_invite", "user_roles"]
        """
        The action group type of the activity log entry.
        """
        user_invite: Optional[UserInvite]
        """
        Details of a user invite action.
        """
        user_roles: Optional[UserRoles]
        """
        Details of a user role change action.
        """
        _inner_class_types = {
            "api_key": ApiKey,
            "user_invite": UserInvite,
            "user_roles": UserRoles,
        }

    actor: Actor
    """
    The actor that performed the action.
    """
    context: str
    """
    The account on which the action was performed.
    """
    created: str
    """
    Timestamp when the activity log entry was created.
    """
    details: Details
    """
    Action-specific details of the activity log entry.
    """
    id: str
    """
    Unique identifier of the activity log entry.
    """
    livemode: bool
    """
    Whether the action was performed in live mode.
    """
    object: Literal["v2.iam.activity_log"]
    """
    String representing the object's type. Objects of the same type share the same value of the object field.
    """
    type: Literal[
        "api_key_created",
        "api_key_deleted",
        "api_key_updated",
        "api_key_viewed",
        "user_invite_accepted",
        "user_invite_created",
        "user_invite_deleted",
        "user_roles_deleted",
        "user_roles_updated",
    ]
    """
    The type of action that was performed.
    """
    _inner_class_types = {"actor": Actor, "details": Details}



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._stripe_object import StripeObject, UntypedStripeObject
from typing import ClassVar, List, Optional
from typing_extensions import Literal


class MetricQueryResult(StripeObject):
    """
    The result of a metric query.
    """

    OBJECT_NAME: ClassVar[Literal["v2.data.analytics.metric_query_result"]] = (
        "v2.data.analytics.metric_query_result"
    )

    class Data(StripeObject):
        class Result(StripeObject):
            currency: Optional[str]
            """
            If this is a monetary metric, the currency it is returned in. Otherwise null.
            """
            metric: str
            """
            The ID of this metric.
            """
            name: str
            """
            The common name of this metric.
            """
            value: int
            """
            The numeric value of this metric.
            """
            _field_encodings = {"value": "int64_string"}

        dimensions: UntypedStripeObject[str]
        """
        A hash of dimension type to dimension instance, if group_by was specified.
        """
        id: str
        """
        A unique identifier for this row.
        """
        results: List[Result]
        """
        Array of metric values returned from this query.
        """
        timestamp: str
        """
        Timestamp denoting the start of this time bucket.
        """
        _inner_class_types = {"results": Result}

    created: str
    """
    The timestamp at which this metric query result was created.
    """
    data: List[Data]
    """
    An array of timeseries data rows.
    """
    id: str
    """
    The unique identifier of this metric query result.
    """
    livemode: bool
    """
    Whether this query was run in live mode.
    """
    next_page_url: Optional[str]
    """
    Pagination future-proofing: URL to fetch the next page; always null for now.
    """
    object: Literal["v2.data.analytics.metric_query_result"]
    """
    String representing the object's type. Objects of the same type share the same value of the object field.
    """
    previous_page_url: Optional[str]
    """
    Pagination future-proofing: URL to fetch the previous page; always null for now.
    """
    refreshed_at: str
    """
    A timestamp representing the freshness of the data this metric is aggregated from.
    """
    _inner_class_types = {"data": Data}



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._stripe_object import StripeObject
from typing import ClassVar
from typing_extensions import Literal


class CustomerConsumerWallet(StripeObject):
    """
    A consumer wallet represents a cryptocurrency wallet address associated with a Crypto Customer.
    """

    OBJECT_NAME: ClassVar[Literal["crypto.consumer_wallet"]] = (
        "crypto.consumer_wallet"
    )
    id: str
    """
    Unique identifier for the object.
    """
    livemode: bool
    """
    If the object exists in live mode, the value is `true`. If the object exists in test mode, the value is `false`.
    """
    network: Literal[
        "aptos",
        "avalanche",
        "base",
        "bitcoin",
        "ethereum",
        "optimism",
        "polygon",
        "solana",
        "stellar",
        "worldchain",
    ]
    """
    The blockchain network for this wallet
    """
    object: Literal["crypto.consumer_wallet"]
    """
    String representing the object's type. Objects of the same type share the same value.
    """
    verified_ownership: bool
    """
    Whether ownership of this wallet has been verified
    """
    wallet_address: str
    """
    The wallet address
    """



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._request_options import RequestOptions
from stripe._stripe_object import UntypedStripeObject
from typing import Any, Dict, List
from typing_extensions import Literal, NotRequired, TypedDict


class FileCreateParams(RequestOptions):
    expand: NotRequired[List[str]]
    """
    Specifies which fields in the response should be expanded.
    """
    file: Any
    """
    A file to upload. Make sure that the specifications follow RFC 2388, which defines file transfers for the `multipart/form-data` protocol.
    """
    file_link_data: NotRequired["FileCreateParamsFileLinkData"]
    """
    Optional parameters that automatically create a [file link](https://api.stripe.com#file_links) for the newly created file.
    """
    purpose: Literal[
        "account_requirement",
        "additional_verification",
        "business_icon",
        "business_logo",
        "customer_signature",
        "dispute_evidence",
        "identity_document",
        "issuing_regulatory_reporting",
        "pci_document",
        "platform_terms_of_service",
        "tax_document_user_upload",
        "terminal_android_apk",
        "terminal_reader_splashscreen",
        "terminal_wifi_certificate",
        "terminal_wifi_private_key",
    ]
    """
    The [purpose](https://docs.stripe.com/file-upload#uploading-a-file) of the uploaded file.
    """


class FileCreateParamsFileLinkData(TypedDict):
    create: bool
    """
    Set this to `true` to create a file link for the newly created file. Creating a link is only possible when the file's `purpose` is one of the following: `business_icon`, `business_logo`, `customer_signature`, `dispute_evidence`, `issuing_regulatory_reporting`, `pci_document`, `tax_document_user_upload`, `terminal_android_apk`, or `terminal_reader_splashscreen`.
    """
    expires_at: NotRequired[int]
    """
    The link isn't available after this future timestamp.
    """
    metadata: NotRequired[
        "Literal['']|Dict[str, str]|UntypedStripeObject[str]"
    ]
    """
    Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.
    """
